@@ -1,28 +1,28 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
 #' Do column data lie between two specified values or data in other columns?
 #'
 #' @description
-#' 
+#'
 #' The `col_vals_between()` validation function, the `expect_col_vals_between()`
 #' expectation function, and the `test_col_vals_between()` test function all
 #' check whether column values in a table fall within a range. The range
@@ -40,45 +40,45 @@
 #' table. Each validation step or expectation will operate over the number of
 #' test units that is equal to the number of rows in the table (after any
 #' `preconditions` have been applied).
-#' 
+#'
 #' @inheritParams col_vals_gt
-#' 
+#'
 #' @param left *Definition of left bound*
-#' 
+#'
 #'   `<value expression>` // **required**
-#' 
+#'
 #'   The lower bound for the range. The validation includes this bound
 #'   value (if the first element in `inclusive` is `TRUE`) in addition to values
 #'   greater than `left`. This can be a single value or a compatible column
 #'   given in `vars()`.
-#'   
+#'
 #' @param right *Definition of right bound*
-#' 
+#'
 #'   `<value expression>` // **required**
-#' 
+#'
 #'   The upper bound for the range. The validation includes this
 #'   bound value (if the second element in `inclusive` is `TRUE`) in addition to
 #'   values lower than `right`. This can be a single value or a compatible
 #'   column given in `vars()`.
-#'   
+#'
 #' @param inclusive *Inclusiveness of bounds*
-#' 
+#'
 #'   `vector<logical>` // *default:* `c(TRUE, TRUE)`
-#' 
+#'
 #'   A two-element logical value that indicates whether the `left` and `right`
 #'   bounds should be inclusive. By default, both bounds are inclusive.
-#'   
+#'
 #' @return For the validation function, the return value is either a
 #'   `ptblank_agent` object or a table object (depending on whether an agent
 #'   object or a table was passed to `x`). The expectation function invisibly
 #'   returns its input but, in the context of testing data, the function is
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
-#' 
+#'
 #' @section Supported Input Tables:
-#' 
+#'
 #' The types of data tables that are officially supported are:
-#' 
+#'
 #'  - data frames (`data.frame`) and tibbles (`tbl_df`)
 #'  - Spark DataFrames (`tbl_spark`)
 #'  - the following database tables (`tbl_dbi`):
@@ -88,34 +88,34 @@
 #'    - *BigQuery* tables (using `bigrquery::bigquery()`)
 #'    - *DuckDB* tables (through `duckdb::duckdb()`)
 #'    - *SQLite* (with `RSQLite::SQLite()`)
-#'    
+#'
 #' Other database tables may work to varying degrees but they haven't been
 #' formally tested (so be mindful of this when using unsupported backends with
 #' **pointblank**).
 #'
 #' @section Column Names:
-#' 
+#'
 #' `columns` may be a single column (as symbol `a` or string `"a"`) or a vector
 #' of columns (`c(a, b, c)` or `c("a", "b", "c")`). `{tidyselect}` helpers
 #' are also supported, such as `contains("date")` and `where(is.double)`. If
 #' passing an *external vector* of columns, it should be wrapped in `all_of()`.
-#' 
+#'
 #' When multiple columns are selected by `columns`, the result will be an
 #' expansion of validation steps to that number of columns (e.g.,
 #' `c(col_a, col_b)` will result in the entry of two validation steps).
-#' 
-#' Previously, columns could be specified in `vars()`. This continues to work, 
+#'
+#' Previously, columns could be specified in `vars()`. This continues to work,
 #' but `c()` offers the same capability and supersedes `vars()` in `columns`.
 #'
 #' @section Missing Values:
-#' 
+#'
 #' This validation function supports special handling of `NA` values. The
 #' `na_pass` argument will determine whether an `NA` value appearing in a test
 #' unit should be counted as a *pass* or a *fail*. The default of `na_pass =
 #' FALSE` means that any `NA`s encountered will accumulate failing test units.
-#' 
+#'
 #' @section Preconditions:
-#' 
+#'
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
 #' the target table during interrogation as a preparatory step. It might happen
 #' that a particular validation requires a calculated column, some filtering of
@@ -132,16 +132,16 @@
 #' serves as the input data table to be transformed (e.g., `~ . %>%
 #' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
 #' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
-#' 
+#'
 #' @section Segments:
-#' 
+#'
 #' By using the `segments` argument, it's possible to define a particular
 #' validation with segments (or row slices) of the target table. An optional
 #' expression or set of expressions that serve to segment the target table by
 #' column values. Each expression can be given in one of two ways: (1) as column
 #' names, or (2) as a two-sided formula where the LHS holds a column name and
 #' the RHS contains the column values to segment on.
-#' 
+#'
 #' As an example of the first type of expression that can be used,
 #' `vars(a_column)` will segment the target table in however many unique values
 #' are present in the column called `a_column`. This is great if every unique
@@ -163,9 +163,9 @@
 #' combo, it's possible to generate labels for segmentation using an expression
 #' for `preconditions` and refer to those labels in `segments` without having to
 #' generate a separate version of the target table.
-#' 
+#'
 #' @section Actions:
-#' 
+#'
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list
 #' object that is best produced by the [action_levels()] function. Read that
@@ -174,36 +174,36 @@
 #' want at least a single threshold level (specified as either the fraction of
 #' test units failed, or, an absolute value), often using the `warn_at`
 #' argument. This is especially true when `x` is a table object because,
-#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using 
+#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using
 #' `action_levels(warn_at = 0.25)` or `action_levels(stop_at = 0.25)` are good
 #' choices depending on the situation (the first produces a warning when a
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
-#' 
+#'
 #' @section Labels:
-#' 
+#'
 #' `label` may be a single string or a character vector that matches the number
 #' of expanded steps. `label` also supports `{glue}` syntax and exposes the
 #' following dynamic variables contextualized to the current step:
-#'   
+#'
 #' - `"{.step}"`: The validation step name
 #' - `"{.col}"`: The current column name
 #' - `"{.seg_col}"`: The current segment's column name
 #' - `"{.seg_val}"`: The current segment's value/group
-#'     
+#'
 #' The glue context also supports ordinary expressions for further flexibility
 #' (e.g., `"{toupper(.step)}"`) as long as they return a length-1 string.
-#' 
+#'
 #' @section Briefs:
-#' 
+#'
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
-#' 
+#'
 #' @section YAML:
-#' 
+#'
 #' A **pointblank** agent can be written to YAML with [yaml_write()] and the
 #' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
 #' or interrogate the target table (via [yaml_agent_interrogate()]). When
@@ -212,11 +212,11 @@
 #' function. Here is an example of how a complex call of `col_vals_between()` as
 #' a validation step is expressed in R code and in the corresponding YAML
 #' representation.
-#' 
+#'
 #' R statement:
-#' 
+#'
 #' ```r
-#' agent %>% 
+#' agent %>%
 #'   col_vals_between(
 #'     columns = a,
 #'     left = 1,
@@ -230,9 +230,9 @@
 #'     active = FALSE
 #'   )
 #' ```
-#' 
+#'
 #' YAML representation:
-#' 
+#'
 #' ```yaml
 #' steps:
 #' - col_vals_between:
@@ -251,30 +251,30 @@
 #'     label: The `col_vals_between()` step.
 #'     active: false
 #' ```
-#' 
+#'
 #' In practice, both of these will often be shorter as only the `columns`,
 #' `left`, and `right` arguments require values. Arguments with default values
 #' won't be written to YAML when using [yaml_write()] (though it is acceptable
 #' to include them with their default when generating the YAML by other means).
 #' It is also possible to preview the transformation of an agent to YAML without
 #' any writing to disk by using the [yaml_agent_string()] function.
-#'   
+#'
 #' @section Examples:
-#' 
+#'
 #' The `small_table` dataset in the package has a column of numeric values in
 #' `c` (there are a few NAs in that column). The following examples will
 #' validate the values in that numeric column.
-#' 
+#'
 #' ```{r}
 #' small_table
 #' ```
-#' 
+#'
 #' ## A: Using an `agent` with validation functions and then `interrogate()`
-#' 
+#'
 #' Validate that values in column `c` are all between `1` and `9`. Because there
 #' are `NA` values, we'll choose to let those pass validation by setting
 #' `na_pass = TRUE`.
-#' 
+#'
 #' ```r
 #' agent <-
 #'   create_agent(tbl = small_table) %>%
@@ -285,23 +285,23 @@
 #'   ) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' Printing the `agent` in the console shows the validation report in the
 #' Viewer. Here is an excerpt of validation report, showing the single entry
 #' that corresponds to the validation step demonstrated here.
-#' 
+#'
 #' \if{html}{
 #' \out{
 #' `r pb_get_image_tag(file = "man_col_vals_between_1.png")`
 #' }
 #' }
-#' 
+#'
 #' ## B: Using the validation function directly on the data (no `agent`)
-#' 
+#'
 #' This way of using validation functions acts as a data filter. Data is passed
 #' through but should `stop()` if there is a single test unit failing. The
 #' behavior of side effects can be customized with the `actions` option.
-#' 
+#'
 #' ```{r}
 #' small_table %>%
 #'   col_vals_between(
@@ -313,10 +313,10 @@
 #' ```
 #'
 #' ## C: Using the expectation function
-#' 
+#'
 #' With the `expect_*()` form, we would typically perform one validation at a
 #' time. This is primarily used in **testthat** tests.
-#' 
+#'
 #' ```r
 #' expect_col_vals_between(
 #'   small_table, columns = c,
@@ -324,12 +324,12 @@
 #'   na_pass = TRUE
 #' )
 #' ```
-#' 
+#'
 #' ## D: Using the test function
-#' 
+#'
 #' With the `test_*()` form, we should get a single logical value returned to
 #' us.
-#' 
+#'
 #' ```{r}
 #' small_table %>%
 #'   test_col_vals_between(
@@ -343,10 +343,10 @@
 #' default (i.e., values of exactly `1` and `9` will pass). We can modify the
 #' inclusiveness of the upper and lower bounds with the `inclusive` option,
 #' which is a length-2 logical vector.
-#' 
+#'
 #' Testing with the upper bound being non-inclusive, we get `FALSE` since two
 #' values are `9` and they now fall outside of the upper (or right) bound.
-#' 
+#'
 #' ```{r}
 #' small_table %>%
 #'   test_col_vals_between(
@@ -355,13 +355,13 @@
 #'     na_pass = TRUE
 #'   )
 #' ```
-#' 
+#'
 #' @family validation functions
 #' @section Function ID:
 #' 2-7
-#' 
+#'
 #' @seealso The analogue to this function: [col_vals_not_between()].
-#' 
+#'
 #' @name col_vals_between
 NULL
 
@@ -383,7 +383,7 @@ col_vals_between <- function(
     brief = NULL,
     active = TRUE
 ) {
-  
+
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
   # Get `columns` as a label
@@ -391,7 +391,7 @@ col_vals_between <- function(
 
   # Resolve the columns based on the expression
   columns <- resolve_columns(x = x, var_expr = columns, preconditions)
-  
+
   # Resolve segments into list
   segments_list <-
     resolve_segments(
@@ -399,13 +399,13 @@ col_vals_between <- function(
       seg_expr = segments,
       preconditions = preconditions
     )
-  
+
   # Set names on the `left` and `right` values
   left <- stats::setNames(left, inclusive[1])
   right <- stats::setNames(right, inclusive[2])
-  
+
   if (is_a_table_object(x)) {
-    
+
     secret_agent <-
       create_agent(x, label = "::QUIET::") %>%
       col_vals_between(
@@ -422,43 +422,43 @@ col_vals_between <- function(
         active = active
       ) %>%
       interrogate()
-    
+
     return(x)
   }
-  
+
   agent <- x
-  
-  if (is.null(brief)) {
-    
-    brief <- 
-      generate_autobriefs(
-        agent = agent,
-        columns = columns,
-        preconditions = preconditions,
-        values = c(left, right),
-        assertion_type = "col_vals_between"
-      )
-  }
-  
+
+  # Avoid rlang (>= 0.3.0) soft deprecation warning
+  # Quosure lists can't be concatenated with objects other than quosures.
+  left <- as.list(left)
+  right <- as.list(right)
+
+  brief <- resolve_brief(
+    brief = brief, agent = agent,
+    columns = columns, segments_list = segments_list,
+    preconditions = preconditions, values = c(left, right),
+    assertion_type = "col_vals_between"
+  )
+
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns, agent)
-  
+
   # Get the next step number for the `validation_set` tibble
   i_o <- get_next_validation_set_row(agent)
-  
+
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
-  
+
   # Add one or more validation steps based on the
   # length of the `columns` variable
   label <- resolve_label(label, columns, segments_list)
   for (i in seq_along(columns)) {
     for (j in seq_along(segments_list)) {
-      
+
       seg_col <- names(segments_list[j])
       seg_val <- unname(unlist(segments_list[j]))
-      
+
       agent <-
         create_validation_step(
           agent = agent,
@@ -475,7 +475,7 @@ col_vals_between <- function(
           actions = covert_actions(actions, agent),
           step_id = step_id[i],
           label = label[[i, j]],
-          brief = brief[i],
+          brief = brief[[i, j]],
           active = active
         )
     }
@@ -497,14 +497,14 @@ expect_col_vals_between <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
+
   fn_name <- "expect_col_vals_between"
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     col_vals_between(
       columns = {{ columns }},
-      left = {{ left }}, 
+      left = {{ left }},
       right = {{ right }},
       inclusive = inclusive,
       na_pass = na_pass,
@@ -513,51 +513,51 @@ expect_col_vals_between <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   x <- vs$notify
-  
+
   threshold_type <- get_threshold_type(threshold = threshold)
-  
+
   if (threshold_type == "proportional") {
     failed_amount <- vs$f_failed
   } else {
     failed_amount <- vs$n_failed
   }
-  
+
   # If several validations were performed serially (due to supplying
   # multiple columns)
   if (length(x) > 1 && any(x)) {
-    
+
     # Get the index (step) of the first failure instance
     fail_idx <- which(x)[1]
-    
+
     # Get the correct, single `failed_amount` for the first
     # failure instance
     failed_amount <- failed_amount[fail_idx]
-    
+
     # Redefine `x` as a single TRUE value
     x <- TRUE
-    
+
   } else {
     x <- any(x)
     fail_idx <- 1
   }
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   act <- testthat::quasi_label(enquo(x), arg = "object")
-  
+
   column_text <- prep_column_text(vs$column[[fail_idx]])
-  value_1 <- 
+  value_1 <-
     prep_values_text(
       values = vs$values[[fail_idx]][[1]], limit = 3, lang = "en"
     )
-  value_2 <- 
+  value_2 <-
     prep_values_text(
       values = vs$values[[fail_idx]][[2]], limit = 3, lang = "en"
     )
@@ -570,9 +570,9 @@ expect_col_vals_between <- function(
       )
     )
   )
-  
+
   act$val <- object
-  
+
   invisible(act$val)
 }
 
@@ -589,12 +589,12 @@ test_col_vals_between <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     col_vals_between(
       columns = {{ columns }},
-      left = {{ left }}, 
+      left = {{ left }},
       right = {{ right }},
       inclusive = inclusive,
       na_pass = na_pass,
@@ -603,13 +603,13 @@ test_col_vals_between <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   all(!vs$notify)
 }
