@@ -1,28 +1,28 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
 #' Are column data decreasing by row?
 #'
 #' @description
-#' 
+#'
 #' The `col_vals_decreasing()` validation function, the
 #' `expect_col_vals_decreasing()` expectation function, and the
 #' `test_col_vals_decreasing()` test function all check whether column values in
@@ -35,40 +35,40 @@
 #' be used with a data table. Each validation step or expectation will operate
 #' over the number of test units that is equal to the number of rows in the
 #' table (after any `preconditions` have been applied).
-#' 
+#'
 #' @inheritParams col_vals_gt
-#' 
+#'
 #' @param allow_stationary *Allowance for stationary pauses in values*
-#' 
+#'
 #'   `scalar<logical>` // *default:* `FALSE`
-#' 
+#'
 #'   An option to allow pauses in decreasing values. For example if the values
 #'   for the test units are `[85, 82, 82, 80, 77]` then the third unit (`82`,
 #'   appearing a second time) would be marked with *fail* when
 #'   `allow_stationary` is `FALSE`. Using `allow_stationary = TRUE` will result
 #'   in all the test units in `[85, 82, 82, 80, 77]` to be marked with *pass*.
-#'   
+#'
 #' @param increasing_tol *Optional tolerance threshold for backtracking*
-#' 
+#'
 #'   `scalar<numeric>(val>=0)` // *default:* `NULL` (`optional`)
-#' 
+#'
 #'   An optional threshold value that allows for movement of numerical values in
 #'   the positive direction. By default this is `NULL` but using a numerical
 #'   value with set the absolute threshold of positive travel allowed across
 #'   numerical test units. Note that setting a value here also has the effect of
 #'   setting `allow_stationary` to `TRUE`.
-#' 
+#'
 #' @return For the validation function, the return value is either a
 #'   `ptblank_agent` object or a table object (depending on whether an agent
 #'   object or a table was passed to `x`). The expectation function invisibly
 #'   returns its input but, in the context of testing data, the function is
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
-#' 
+#'
 #' @section Supported Input Tables:
-#' 
+#'
 #' The types of data tables that are officially supported are:
-#' 
+#'
 #'  - data frames (`data.frame`) and tibbles (`tbl_df`)
 #'  - Spark DataFrames (`tbl_spark`)
 #'  - the following database tables (`tbl_dbi`):
@@ -78,34 +78,34 @@
 #'    - *BigQuery* tables (using `bigrquery::bigquery()`)
 #'    - *DuckDB* tables (through `duckdb::duckdb()`)
 #'    - *SQLite* (with `RSQLite::SQLite()`)
-#'    
+#'
 #' Other database tables may work to varying degrees but they haven't been
 #' formally tested (so be mindful of this when using unsupported backends with
 #' **pointblank**).
 #'
 #' @section Column Names:
-#' 
+#'
 #' `columns` may be a single column (as symbol `a` or string `"a"`) or a vector
 #' of columns (`c(a, b, c)` or `c("a", "b", "c")`). `{tidyselect}` helpers
 #' are also supported, such as `contains("date")` and `where(is.double)`. If
 #' passing an *external vector* of columns, it should be wrapped in `all_of()`.
-#' 
+#'
 #' When multiple columns are selected by `columns`, the result will be an
 #' expansion of validation steps to that number of columns (e.g.,
 #' `c(col_a, col_b)` will result in the entry of two validation steps).
-#' 
-#' Previously, columns could be specified in `vars()`. This continues to work, 
+#'
+#' Previously, columns could be specified in `vars()`. This continues to work,
 #' but `c()` offers the same capability and supersedes `vars()` in `columns`.
 #'
 #' @section Missing Values:
-#' 
+#'
 #' This validation function supports special handling of `NA` values. The
 #' `na_pass` argument will determine whether an `NA` value appearing in a test
 #' unit should be counted as a *pass* or a *fail*. The default of `na_pass =
 #' FALSE` means that any `NA`s encountered will accumulate failing test units.
-#' 
+#'
 #' @section Preconditions:
-#' 
+#'
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
 #' the target table during interrogation as a preparatory step. It might happen
 #' that a particular validation requires a calculated column, some filtering of
@@ -122,16 +122,16 @@
 #' serves as the input data table to be transformed (e.g., `~ . %>%
 #' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
 #' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
-#' 
+#'
 #' @section Segments:
-#' 
+#'
 #' By using the `segments` argument, it's possible to define a particular
 #' validation with segments (or row slices) of the target table. An optional
 #' expression or set of expressions that serve to segment the target table by
 #' column values. Each expression can be given in one of two ways: (1) as column
 #' names, or (2) as a two-sided formula where the LHS holds a column name and
 #' the RHS contains the column values to segment on.
-#' 
+#'
 #' As an example of the first type of expression that can be used,
 #' `vars(a_column)` will segment the target table in however many unique values
 #' are present in the column called `a_column`. This is great if every unique
@@ -153,9 +153,9 @@
 #' combo, it's possible to generate labels for segmentation using an expression
 #' for `preconditions` and refer to those labels in `segments` without having to
 #' generate a separate version of the target table.
-#' 
+#'
 #' @section Actions:
-#' 
+#'
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list
 #' object that is best produced by the [action_levels()] function. Read that
@@ -164,36 +164,36 @@
 #' want at least a single threshold level (specified as either the fraction of
 #' test units failed, or, an absolute value), often using the `warn_at`
 #' argument. This is especially true when `x` is a table object because,
-#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using 
+#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using
 #' `action_levels(warn_at = 0.25)` or `action_levels(stop_at = 0.25)` are good
 #' choices depending on the situation (the first produces a warning when a
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
-#' 
+#'
 #' @section Labels:
-#' 
+#'
 #' `label` may be a single string or a character vector that matches the number
 #' of expanded steps. `label` also supports `{glue}` syntax and exposes the
 #' following dynamic variables contextualized to the current step:
-#'   
+#'
 #' - `"{.step}"`: The validation step name
 #' - `"{.col}"`: The current column name
 #' - `"{.seg_col}"`: The current segment's column name
 #' - `"{.seg_val}"`: The current segment's value/group
-#'     
+#'
 #' The glue context also supports ordinary expressions for further flexibility
 #' (e.g., `"{toupper(.step)}"`) as long as they return a length-1 string.
-#' 
+#'
 #' @section Briefs:
-#' 
+#'
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
-#' 
+#'
 #' @section YAML:
-#' 
+#'
 #' A **pointblank** agent can be written to YAML with [yaml_write()] and the
 #' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
 #' or interrogate the target table (via [yaml_agent_interrogate()]). When
@@ -202,11 +202,11 @@
 #' validation function. Here is an example of how a complex call of
 #' `col_vals_decreasing()` as a validation step is expressed in R code and in
 #' the corresponding YAML representation.
-#' 
+#'
 #' R statement:
-#' 
+#'
 #' ```r
-#' agent %>% 
+#' agent %>%
 #'   col_vals_decreasing(
 #'     columns = a,
 #'     allow_stationary = TRUE,
@@ -219,9 +219,9 @@
 #'     active = FALSE
 #'   )
 #' ```
-#' 
+#'
 #' YAML representation:
-#' 
+#'
 #' ```yaml
 #' steps:
 #' - col_vals_decreasing:
@@ -237,43 +237,43 @@
 #'     label: The `col_vals_decreasing()` step.
 #'     active: false
 #' ```
-#' 
+#'
 #' In practice, both of these will often be shorter as only the `columns`
 #' argument requires a value. Arguments with default values won't be written to
 #' YAML when using [yaml_write()] (though it is acceptable to include them with
 #' their default when generating the YAML by other means). It is also possible
 #' to preview the transformation of an agent to YAML without any writing to disk
 #' by using the [yaml_agent_string()] function.
-#' 
+#'
 #' @section Examples:
-#' 
+#'
 #' The `game_revenue` dataset in the package has the column `session_start`,
 #' which contains date-time values. Let's create a column of difftime values (in
 #' `time_left`) that describes the time remaining in the month relative to the
 #' session start.
-#' 
+#'
 #' ```{r}
 #' game_revenue_2 <-
 #'   game_revenue %>%
 #'   dplyr::mutate(
-#'     time_left = 
+#'     time_left =
 #'       lubridate::ymd_hms(
 #'         "2015-02-01 00:00:00"
 #'       ) - session_start
 #'   )
-#' 
+#'
 #' game_revenue_2
 #' ```
-#' 
+#'
 #' Let's ensure that the `"difftime"` values in the new `time_left` column has
 #' values that are decreasing from top to bottom.
 #'
 #' ## A: Using an `agent` with validation functions and then `interrogate()`
-#' 
+#'
 #' Validate that all `"difftime"` values in the column `time_left` are
 #' decreasing, and, allow for repeating values (`allow_stationary` will be set
 #' to `TRUE`).
-#' 
+#'
 #' ```r
 #' agent <-
 #'   create_agent(tbl = game_revenue_2) %>%
@@ -283,23 +283,23 @@
 #'   ) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' Printing the `agent` in the console shows the validation report in the
 #' Viewer. Here is an excerpt of validation report, showing the single entry
 #' that corresponds to the validation step demonstrated here.
-#' 
+#'
 #' \if{html}{
 #' \out{
 #' `r pb_get_image_tag(file = "man_col_vals_decreasing_1.png")`
 #' }
 #' }
-#' 
+#'
 #' ## B: Using the validation function directly on the data (no `agent`)
-#' 
+#'
 #' This way of using validation functions acts as a data filter. Data is passed
 #' through but should `stop()` if there is a single test unit failing. The
 #' behavior of side effects can be customized with the `actions` option.
-#' 
+#'
 #' ```{r}
 #' game_revenue_2 %>%
 #'   col_vals_decreasing(
@@ -312,10 +312,10 @@
 #' ```
 #'
 #' ## C: Using the expectation function
-#' 
+#'
 #' With the `expect_*()` form, we would typically perform one validation at a
 #' time. This is primarily used in **testthat** tests.
-#' 
+#'
 #' ```r
 #' expect_col_vals_decreasing(
 #'   game_revenue_2,
@@ -323,12 +323,12 @@
 #'   allow_stationary = TRUE
 #' )
 #' ```
-#' 
+#'
 #' ## D: Using the test function
-#' 
+#'
 #' With the `test_*()` form, we should get a single logical value returned to
 #' us.
-#' 
+#'
 #' ```{r}
 #' game_revenue_2 %>%
 #'   test_col_vals_decreasing(
@@ -336,14 +336,14 @@
 #'     allow_stationary = TRUE
 #'   )
 #' ```
-#' 
+#'
 #' @family validation functions
 #' @section Function ID:
 #' 2-14
-#' 
+#'
 #' @seealso The analogous function that moves in the opposite direction:
 #' [col_vals_increasing()].
-#' 
+#'
 #' @name col_vals_decreasing
 NULL
 
@@ -364,15 +364,15 @@ col_vals_decreasing <- function(
     brief = NULL,
     active = TRUE
 ) {
-  
+
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
   # Get `columns` as a label
   columns_expr <- as_columns_expr(columns)
-  
+
   # Resolve the columns based on the expression
   columns <- resolve_columns(x = x, var_expr = columns, preconditions)
-  
+
   # Resolve segments into list
   segments_list <-
     resolve_segments(
@@ -380,18 +380,18 @@ col_vals_decreasing <- function(
       seg_expr = segments,
       preconditions = preconditions
     )
-  
+
   # TODO: Ensure that `allow_stationary` is logical
   # TODO: Ensure that `increasing_tol` is either `NULL` or numeric
-  
+
   # Put `allow_stationary` and `increasing_tol` into a length-2 numeric vector
-  stat_tol <- 
+  stat_tol <-
     as.numeric(
       c(allow_stationary, if (is.null(increasing_tol)) 0 else increasing_tol)
     )
-  
+
   if (is_a_table_object(x)) {
-    
+
     secret_agent <-
       create_agent(x, label = "::QUIET::") %>%
       col_vals_decreasing(
@@ -407,43 +407,38 @@ col_vals_decreasing <- function(
         active = active
       ) %>%
       interrogate()
-    
+
     return(x)
   }
-  
+
   agent <- x
-  
-  if (is.null(brief)) {
-    
-    brief <- 
-      generate_autobriefs(
-        agent = agent,
-        columns = columns,
-        preconditions = preconditions,
-        values = increasing_tol,
-        assertion_type = "col_vals_decreasing"
-      )
-  }
-  
+
+  brief <- resolve_brief(
+    brief = brief, agent = agent,
+    columns = columns, segments_list = segments_list,
+    preconditions = preconditions, values = increasing_tol,
+    assertion_type = "col_vals_decreasing"
+  )
+
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns, agent)
-  
+
   # Get the next step number for the `validation_set` tibble
   i_o <- get_next_validation_set_row(agent)
-  
+
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
-  
+
   # Add one or more validation steps based on the
   # length of the `columns` variable
   label <- resolve_label(label, columns, segments_list)
   for (i in seq_along(columns)) {
     for (j in seq_along(segments_list)) {
-      
+
       seg_col <- names(segments_list[j])
       seg_val <- unname(unlist(segments_list[j]))
-      
+
       agent <-
         create_validation_step(
           agent = agent,
@@ -460,12 +455,12 @@ col_vals_decreasing <- function(
           actions = covert_actions(actions, agent),
           step_id = step_id[i],
           label = label[[i, j]],
-          brief = brief[i],
+          brief = brief[[i, j]],
           active = active
         )
     }
   }
-  
+
   agent
 }
 
@@ -481,10 +476,10 @@ expect_col_vals_decreasing <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
+
   fn_name <- "expect_col_vals_decreasing"
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     col_vals_decreasing(
       columns = {{ columns }},
@@ -496,47 +491,47 @@ expect_col_vals_decreasing <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   x <- vs$notify
-  
+
   threshold_type <- get_threshold_type(threshold = threshold)
-  
+
   if (threshold_type == "proportional") {
     failed_amount <- vs$f_failed
   } else {
     failed_amount <- vs$n_failed
   }
-  
+
   # If several validations were performed serially (due to supplying
   # multiple columns)
   if (length(x) > 1 && any(x)) {
-    
+
     # Get the index (step) of the first failure instance
     fail_idx <- which(x)[1]
-    
+
     # Get the correct, single `failed_amount` for the first
     # failure instance
     failed_amount <- failed_amount[fail_idx]
-    
+
     # Redefine `x` as a single TRUE value
     x <- TRUE
-    
+
   } else {
     x <- any(x)
     fail_idx <- 1
   }
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   act <- testthat::quasi_label(enquo(x), arg = "object")
-  
+
   column_text <- prep_column_text(vs$column[[fail_idx]])
-  
+
   testthat::expect(
     ok = identical(!as.vector(act$val), TRUE),
     failure_message = glue::glue(
@@ -545,9 +540,9 @@ expect_col_vals_decreasing <- function(
       )
     )
   )
-  
+
   act$val <- object
-  
+
   invisible(act$val)
 }
 
@@ -563,8 +558,8 @@ test_col_vals_decreasing <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     col_vals_decreasing(
       columns = {{ columns }},
@@ -576,13 +571,13 @@ test_col_vals_decreasing <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   all(!vs$notify)
 }
