@@ -1,28 +1,28 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
 #' Perform multiple rowwise validations for joint validity
 #'
 #' @description
-#' 
+#'
 #' The `conjointly()` validation function, the `expect_conjointly()` expectation
 #' function, and the `test_conjointly()` test function all check whether test
 #' units at each index (typically each row) all pass multiple validations. We
@@ -32,7 +32,7 @@
 #' validation functions, the ensemble of test units are either comprised rows of
 #' the table (after any common `preconditions` have been applied) or are single
 #' test units (for those functions that validate columns).
-#' 
+#'
 #' Each of the functions used in a `conjointly()` validation step (composed
 #' using multiple validation function calls) ultimately perform a rowwise test
 #' of whether all sub-validations reported a *pass* for the same test units. In
@@ -44,22 +44,22 @@
 #' function can be used directly on a data table or with an *agent* object
 #' (technically, a `ptblank_agent` object) whereas the expectation and test
 #' functions can only be used with a data table.
-#' 
+#'
 #' @inheritParams col_vals_gt
-#' 
+#'
 #' @param ... *Validation expressions*
-#' 
+#'
 #'   `<validation expressions>` // **required** (or, use `.list`)
-#' 
+#'
 #'   A collection one-sided formulas that consist of validation functions that
 #'   validate row units (the `col_vals_*()` series), column existence
 #'   ([col_exists()]), or column type (the `col_is_*()` series). An example of
 #'   this is `~ col_vals_gte(., a, 5.5), ~ col_vals_not_null(., b`).
-#' 
+#'
 #' @param .list *Alternative to `...`*
-#' 
+#'
 #'   `<list of multiple expressions>` // **required** (or, use `...`)
-#' 
+#'
 #'   Allows for the use of a list as an input alternative to `...`.
 #'
 #' @return For the validation function, the return value is either a
@@ -68,11 +68,11 @@
 #'   returns its input but, in the context of testing data, the function is
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
-#' 
+#'
 #' @section Supported Input Tables:
-#' 
+#'
 #' The types of data tables that are officially supported are:
-#' 
+#'
 #'  - data frames (`data.frame`) and tibbles (`tbl_df`)
 #'  - Spark DataFrames (`tbl_spark`)
 #'  - the following database tables (`tbl_dbi`):
@@ -82,27 +82,27 @@
 #'    - *BigQuery* tables (using `bigrquery::bigquery()`)
 #'    - *DuckDB* tables (through `duckdb::duckdb()`)
 #'    - *SQLite* (with `RSQLite::SQLite()`)
-#'    
+#'
 #' Other database tables may work to varying degrees but they haven't been
 #' formally tested (so be mindful of this when using unsupported backends with
 #' **pointblank**).
 #'
 #' @section Column Names:
-#' 
+#'
 #' `columns` may be a single column (as symbol `a` or string `"a"`) or a vector
 #' of columns (`c(a, b, c)` or `c("a", "b", "c")`). `{tidyselect}` helpers
 #' are also supported, such as `contains("date")` and `where(is.double)`. If
 #' passing an *external vector* of columns, it should be wrapped in `all_of()`.
-#' 
+#'
 #' When multiple columns are selected by `columns`, the result will be an
 #' expansion of validation steps to that number of columns (e.g.,
 #' `c(col_a, col_b)` will result in the entry of two validation steps).
-#' 
-#' Previously, columns could be specified in `vars()`. This continues to work, 
+#'
+#' Previously, columns could be specified in `vars()`. This continues to work,
 #' but `c()` offers the same capability and supersedes `vars()` in `columns`.
-#' 
+#'
 #' @section Preconditions:
-#' 
+#'
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
 #' the target table during interrogation as a preparatory step. It might happen
 #' that a particular validation requires a calculated column, some filtering of
@@ -119,16 +119,16 @@
 #' serves as the input data table to be transformed (e.g., `~ . %>%
 #' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
 #' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
-#' 
+#'
 #' @section Segments:
-#' 
+#'
 #' By using the `segments` argument, it's possible to define a particular
 #' validation with segments (or row slices) of the target table. An optional
 #' expression or set of expressions that serve to segment the target table by
 #' column values. Each expression can be given in one of two ways: (1) as column
 #' names, or (2) as a two-sided formula where the LHS holds a column name and
 #' the RHS contains the column values to segment on.
-#' 
+#'
 #' As an example of the first type of expression that can be used,
 #' `vars(a_column)` will segment the target table in however many unique values
 #' are present in the column called `a_column`. This is great if every unique
@@ -150,9 +150,9 @@
 #' combo, it's possible to generate labels for segmentation using an expression
 #' for `preconditions` and refer to those labels in `segments` without having to
 #' generate a separate version of the target table.
-#' 
+#'
 #' @section Actions:
-#' 
+#'
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list
 #' object that is best produced by the [action_levels()] function. Read that
@@ -161,35 +161,35 @@
 #' want at least a single threshold level (specified as either the fraction of
 #' test units failed, or, an absolute value), often using the `warn_at`
 #' argument. This is especially true when `x` is a table object because,
-#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using 
+#' otherwise, nothing happens. For the `col_vals_*()`-type functions, using
 #' `action_levels(warn_at = 0.25)` or `action_levels(stop_at = 0.25)` are good
 #' choices depending on the situation (the first produces a warning when a
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
-#' 
+#'
 #' @section Labels:
-#' 
+#'
 #' `label` may be a single string or a character vector that matches the number
 #' of expanded steps. `label` also supports `{glue}` syntax and exposes the
 #' following dynamic variables contextualized to the current step:
-#'   
+#'
 #' - `"{.step}"`: The validation step name
 #' - `"{.seg_col}"`: The current segment's column name
 #' - `"{.seg_val}"`: The current segment's value/group
-#'     
+#'
 #' The glue context also supports ordinary expressions for further flexibility
 #' (e.g., `"{toupper(.step)}"`) as long as they return a length-1 string.
-#' 
+#'
 #' @section Briefs:
-#' 
+#'
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
-#' 
+#'
 #' @section YAML:
-#' 
+#'
 #' A **pointblank** agent can be written to YAML with [yaml_write()] and the
 #' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
 #' or interrogate the target table (via [yaml_agent_interrogate()]). When
@@ -198,25 +198,25 @@
 #' function. Here is an example of how a complex call of `conjointly()` as a
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
-#' 
+#'
 #' R statement:
-#' 
+#'
 #' ```r
-#' agent %>% 
+#' agent %>%
 #'   conjointly(
 #'     ~ col_vals_lt(., columns = a, value = 8),
 #'     ~ col_vals_gt(., columns = c, value = vars(a)),
 #'     ~ col_vals_not_null(., columns = b),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
 #'     segments = b ~ c("group_1", "group_2"),
-#'     actions = action_levels(warn_at = 0.1, stop_at = 0.2), 
+#'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `conjointly()` step.",
 #'     active = FALSE
 #'   )
 #' ```
-#' 
+#'
 #' YAML representation:
-#' 
+#'
 #' ```yaml
 #' steps:
 #' - conjointly:
@@ -232,7 +232,7 @@
 #'     label: The `conjointly()` step.
 #'     active: false
 #' ```
-#' 
+#'
 #' In practice, both of these will often be shorter as only the expressions for
 #' validation steps are necessary. Arguments with default values won't be
 #' written to YAML when using [yaml_write()] (though it is acceptable to include
@@ -241,11 +241,11 @@
 #' writing to disk by using the [yaml_agent_string()] function.
 #'
 #' @section Examples:
-#' 
+#'
 #' For all examples here, we'll use a simple table with three numeric columns
 #' (`a`, `b`, and `c`). This is a very basic table but it'll be more useful when
 #' explaining things later.
-#' 
+#'
 #' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
@@ -253,19 +253,19 @@
 #'     b = c(3, 4, 6),
 #'     c = c(9, 8, 7)
 #'   )
-#'   
+#'
 #' tbl
 #' ```
-#'   
+#'
 #' ## A: Using an `agent` with validation functions and then `interrogate()`
-#' 
+#'
 #' Validate a number of things on a row-by-row basis using validation functions
 #' of the `col_vals*` type (all have the same number of test units): (1) values
 #' in `a` are less than `8`, (2) values in `c` are greater than the adjacent
 #' values in `a`, and (3) there aren't any NA values in `b`. We'll determine if
 #' this validation has any failing test units (there are 3 test units, one for
 #' each row).
-#' 
+#'
 #' ```r
 #' agent <-
 #'   create_agent(tbl = tbl) %>%
@@ -276,28 +276,28 @@
 #'     ) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' Printing the `agent` in the console shows the validation report in the
 #' Viewer. Here is an excerpt of validation report, showing the single entry
 #' that corresponds to the validation step demonstrated here.
-#' 
+#'
 #' \if{html}{
 #' \out{
 #' `r pb_get_image_tag(file = "man_conjointly_1.png")`
 #' }
 #' }
-#' 
+#'
 #' What's going on? Think of there being three parallel validations, each
 #' producing a column of `TRUE` or `FALSE` values (`pass` or `fail`) and line
 #' them up side-by-side, any rows with any `FALSE` values results in a conjoint
 #' `fail` test unit.
-#' 
+#'
 #' ## B: Using the validation function directly on the data (no `agent`)
-#' 
+#'
 #' This way of using validation functions acts as a data filter. Data is passed
 #' through but should `stop()` if there is a single test unit failing. The
 #' behavior of side effects can be customized with the `actions` option.
-#' 
+#'
 #' ```{r}
 #' tbl %>%
 #'   conjointly(
@@ -308,10 +308,10 @@
 #' ```
 #'
 #' ## C: Using the expectation function
-#' 
+#'
 #' With the `expect_*()` form, we would typically perform one validation at a
 #' time. This is primarily used in **testthat** tests.
-#' 
+#'
 #' ```r
 #' expect_conjointly(
 #'   tbl,
@@ -320,12 +320,12 @@
 #'   ~ col_vals_not_null(., columns = b)
 #' )
 #' ```
-#' 
+#'
 #' ## D: Using the test function
-#' 
+#'
 #' With the `test_*()` form, we should get a single logical value returned to
 #' us.
-#' 
+#'
 #' ```{r}
 #' tbl %>%
 #'   test_conjointly(
@@ -334,7 +334,7 @@
 #'     ~ col_vals_not_null(., columns = b)
 #'   )
 #' ```
-#' 
+#'
 #' @family validation functions
 #' @section Function ID:
 #' 2-34
@@ -360,9 +360,9 @@ conjointly <- function(
 
   # Obtain all of the group's elements
   list_elements <- .list
-  
+
   dots_attrs <- list_elements[rlang::names2(list_elements) != ""]
-  
+
   validation_formulas <-
     list_elements[
       vapply(
@@ -372,7 +372,7 @@ conjointly <- function(
         USE.NAMES = FALSE
       )
     ]
-  
+
   # Resolve segments into list
   segments_list <-
     resolve_segments(
@@ -380,9 +380,9 @@ conjointly <- function(
       seg_expr = segments,
       preconditions = preconditions
     )
-  
+
   if (is_a_table_object(x)) {
-    
+
     secret_agent <-
       create_agent(x, label = "::QUIET::") %>%
       conjointly(
@@ -395,29 +395,25 @@ conjointly <- function(
         active = active
       ) %>%
       interrogate()
-    
+
     return(x)
   }
-  
+
   agent <- x
-  
-  if (is.null(brief)) {
-    
-    brief <-
-      create_autobrief(
-        agent = agent,
-        assertion_type = "conjointly",
-        preconditions = preconditions,
-        values = validation_formulas
-      )
-  }
-  
+
+  brief <- resolve_brief(
+    brief = brief, agent = agent,
+    segments_list = segments_list,
+    preconditions = preconditions, values = validation_formulas,
+    assertion_type = "conjointly"
+  )
+
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns = "column", agent)
-  
+
   # Get the next step number for the `validation_set` tibble
   i_o <- get_next_validation_set_row(agent)
-  
+
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
@@ -426,10 +422,10 @@ conjointly <- function(
   # length of `segments_list`
   label <- resolve_label(label, segments = segments_list)
   for (i in seq_along(segments_list)) {
-    
+
     seg_col <- names(segments_list[i])
     seg_val <- unname(unlist(segments_list[i]))
-    
+
     agent <-
       create_validation_step(
         agent = agent,
@@ -446,11 +442,11 @@ conjointly <- function(
         actions = covert_actions(actions, agent),
         step_id = step_id,
         label = label[[i]],
-        brief = brief,
+        brief = brief[[i]],
         active = active
       )
   }
-  
+
   agent
 }
 
@@ -464,10 +460,10 @@ expect_conjointly <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
+
   fn_name <- "expect_conjointly"
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     conjointly(
       .list = .list,
@@ -476,23 +472,23 @@ expect_conjointly <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   x <- vs$notify %>% all()
-  
+
   threshold_type <- get_threshold_type(threshold = threshold)
-  
+
   if (threshold_type == "proportional") {
     failed_amount <- vs$f_failed
   } else {
     failed_amount <- vs$n_failed
   }
-  
+
   # TODO: express warnings and errors here
-  
+
   act <- testthat::quasi_label(enquo(x), arg = "object")
-  
+
   values_text <- prep_values_text(values = vs$values, limit = 3, lang = "en")
-  
+
   testthat::expect(
     ok = identical(!as.vector(act$val), TRUE),
     failure_message = glue::glue(
@@ -501,9 +497,9 @@ expect_conjointly <- function(
       )
     )
   )
-  
+
   act$val <- object
-  
+
   invisible(act$val)
 }
 
@@ -517,8 +513,8 @@ test_conjointly <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     conjointly(
       .list = .list,
@@ -527,13 +523,13 @@ test_conjointly <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   all(!vs$notify)
 }
