@@ -1,45 +1,45 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
 #' Get a summary report using multiple agents
-#' 
+#'
 #' @description
-#' 
+#'
 #' We can get an informative summary table from a collective of agents by using
 #' the `get_multiagent_report()` function. Information from multiple agent can
 #' be provided in three very forms: (1) the *Long Display* (stacked reports),
 #' (2) the *Wide Display* (a comparison report), (3) as a tibble with packed
 #' columns.
-#' 
+#'
 #' @param multiagent A multiagent object of class `ptblank_multiagent`.
-#' 
+#'
 #' @param display_table Should a display table be generated? If `TRUE` (the
 #'   default) a display table for the report will be shown in the Viewer. If
 #'   `FALSE` then a tibble will be returned.
-#'   
+#'
 #' @param display_mode If we are getting a display table, should the agent data
 #'   be presented in a `"long"` or `"wide"` form? The default is `"long"` but
 #'   when comparing multiple runs where the target table is the same it might be
 #'   preferable to choose `"wide"`.
-#'   
+#'
 #' @param title Options for customizing the title of the report when
 #'   `display_table = TRUE`. The default is the keyword `":default:"` which
 #'   produces generic title text. If no title is wanted, then the `":none:"`
@@ -51,11 +51,11 @@
 #'   Markdown text and transformed internally to HTML. To circumvent such a
 #'   transformation, use text in [I()] to explicitly state that the supplied
 #'   text should not be transformed.
-#'   
+#'
 #' @param lang *Reporting language*
-#' 
+#'
 #'   `scalar<character>` // *default:* `NULL` (`optional`)
-#' 
+#'
 #'   The language to use for the long or wide report forms. By default, `NULL`
 #'   will preserve any language set in the component reports. The following
 #'   options will force the same language across all component reports: English
@@ -63,33 +63,33 @@
 #'   (`"es"`), Portuguese (`"pt"`), Turkish (`"tr"`), Chinese (`"zh"`), Russian
 #'   (`"ru"`), Polish (`"pl"`), Danish (`"da"`), Swedish (`"sv"`), and Dutch
 #'   (`"nl"`).
-#'   
+#'
 #' @param locale *Locale for value formatting*
-#' 
+#'
 #'   `scalar<character>` // *default:* `NULL` (`optional`)
-#' 
+#'
 #'   An optional locale ID to use for formatting values in the long or wide
 #'   report forms (according the locale's rules). Examples include `"en_US"` for
 #'   English (United States) and `"fr_FR"` for French (France); more simply,
 #'   this can be a language identifier without a country designation, like
 #'   `"es"` for Spanish (Spain, same as `"es_ES"`). This `locale` option will
 #'   override any previously set locale values.
-#' 
+#'
 #' @return A **gt** table object if `display_table = TRUE` or a tibble if
 #'   `display_table = FALSE`.
-#' 
+#'
 #' @section The Long Display:
-#' 
+#'
 #' When displayed as `"long"` the multiagent report will stack individual agent
 #' reports in a single document in the order of the agents in the multiagent
 #' object.
-#' 
+#'
 #' Each validation plan (possibly with interrogation info) will be provided and
 #' the output for each is equivalent to calling [get_agent_report()] on each
 #' of the agents within the multiagent object.
-#' 
+#'
 #' @section The Wide Display:
-#' 
+#'
 #' When displayed as `"wide"` the multiagent report will show data from
 #' individual agents as columns, with rows standing as validation steps common
 #' across the agents.
@@ -102,42 +102,42 @@
 #' to track the validation results where the validation step doesn't change but
 #' the target table does (i.e., new rows are added, existing rows are updated,
 #' etc.).
-#' 
+#'
 #' The single table from this display mode will have the following columns:
-#' 
+#'
 #' - STEP: the SHA1 hash for the validation step, possibly shared among
 #' several interrogations.
 #' - *subsequent columns*: each column beyond `STEP` represents a separate
 #' interrogation from an *agent* object. The time stamp for the completion of
 #' each interrogation is shown as the column label.
-#' 
+#'
 #' @section Examples:
-#' 
+#'
 #' Let's walk through several theoretical data quality analyses of an extremely
 #' small table. that table is called `small_table` and we can find it as a
 #' dataset in this package.
-#' 
+#'
 #' ```{r}
 #' small_table
 #' ```
-#' 
+#'
 #' To set failure limits and signal conditions, we designate proportional
 #' failure thresholds to the `warn`, `stop`, and `notify` states using
 #' `action_levels()`.
-#' 
+#'
 #' ```r
-#' al <- 
+#' al <-
 #'   action_levels(
 #'     warn_at = 0.05,
 #'     stop_at = 0.10,
 #'     notify_at = 0.20
 #'   )
 #' ```
-#' 
+#'
 #' We will create four different agents and have slightly different validation
 #' steps in each of them. In the first, `agent_1`, eight different validation
 #' steps are created and the agent will interrogate the `small_table`.
-#' 
+#'
 #' ```r
 #' agent_1 <-
 #'   create_agent(
@@ -151,18 +151,18 @@
 #'     na_pass = TRUE
 #'   ) %>%
 #'   col_vals_gt(
-#'     columns = b, 
+#'     columns = b,
 #'     value = vars(g),
 #'     na_pass = TRUE
 #'   ) %>%
 #'   rows_distinct() %>%
 #'   col_vals_equal(
-#'     columns = d, 
+#'     columns = d,
 #'     value = vars(d),
 #'     na_pass = TRUE
 #'   ) %>%
 #'   col_vals_between(
-#'     columns = c, 
+#'     columns = c,
 #'     left = vars(a), right = vars(d)
 #'   ) %>%
 #'   col_vals_not_between(
@@ -174,27 +174,27 @@
 #'   col_is_integer(columns = a) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' The second agent, `agent_2`, retains all of the steps of `agent_1` and adds
 #' two more (the last of which is inactive).
-#' 
+#'
 #' ```r
-#' agent_2 <- 
+#' agent_2 <-
 #'   agent_1 %>%
 #'   col_exists(columns = date, date_time) %>%
 #'   col_vals_regex(
-#'     columns = b, 
+#'     columns = b,
 #'     regex = "[0-9]-[a-z]{3}-[0-9]{3}",
 #'     active = FALSE
 #'   ) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' The third agent, `agent_3`, adds a single validation step, removes the fifth
 #' one, and deactivates the first.
-#' 
+#'
 #' ```r
-#' agent_3 <- 
+#' agent_3 <-
 #'   agent_2 %>%
 #'   col_vals_in_set(
 #'     columns = f,
@@ -204,10 +204,10 @@
 #'   deactivate_steps(i = 1) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' The fourth and final agent, `agent_4`, reactivates steps 1 and 10, and
 #' removes the sixth step.
-#' 
+#'
 #' ```r
 #' agent_4 <-
 #'   agent_3 %>%
@@ -216,39 +216,39 @@
 #'   remove_steps(i = 6) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' While all the agents are slightly different from each other, we can still get
 #' a combined report of them by creating a 'multiagent'.
-#' 
+#'
 #' ```r
 #' multiagent <-
 #'   create_multiagent(
 #'     agent_1, agent_2, agent_3, agent_4
 #'   )
 #' ```
-#' 
+#'
 #' Calling `multiagent` in the console prints the multiagent report. But we can
 #' generate a `"ptblank_multiagent_report"` object with the
 #' `get_multiagent_report()` function and specify options for layout and
 #' presentation.
-#' 
+#'
 #' By default, `get_multiagent_report()` gives you a long report with agent
 #' reports being stacked. Think of this `"long"` option as the serial mode of
 #' agent reports. However if we want to view interrogation results of the same
 #' table over time, the wide view may be preferable. In this way we can see
 #' whether the results of common validation steps improved or worsened over
 #' consecutive interrogations of the data.
-#' 
+#'
 #' ```r
-#' report_wide <- 
+#' report_wide <-
 #'   get_multiagent_report(
 #'     multiagent,
 #'     display_mode = "wide"
 #'   )
-#'   
+#'
 #' report_wide
 #' ```
-#' 
+#'
 #' \if{html}{
 #' \out{
 #' `r pb_get_image_tag(file = "man_get_multiagent_report_1.png")`
@@ -272,15 +272,15 @@ get_multiagent_report <- function(
   if (is.null(lang)) {
     lang <- "en"
   }
-  
+
   for (i in seq_along(multiagent[["agents"]])) {
-    
+
     time_end <- gsub(" ", "T", multiagent[["agents"]][[i]][["time_end"]])
-    
+
     i_name <- paste0(formatC(i, width = 3, flag = 0), "_", time_end)
     i_name <- rlang::quo_name(i_name)
-    
-    val_set_packed <- 
+
+    val_set_packed <-
       multiagent[["agents"]][[i]][["validation_set"]] %>%
       dplyr::select(
         sha1, i, step_id, assertion_type, column, values,
@@ -295,33 +295,33 @@ get_multiagent_report <- function(
         n, f_passed, f_failed, warn, notify, stop
       )) %>%
       dplyr::rename(!!i_name := "validation")
-    
+
     if (i == 1) {
       report_tbl <- val_set_packed
       next
     }
-    
+
     report_tbl <-
       report_tbl %>%
       dplyr::full_join(val_set_packed, by = "sha1")
   }
-  
+
   report_tbl <-
     report_tbl %>%
     dplyr::select(-sha1)
-  
+
   if (!display_table) {
     return(report_tbl)
   }
 
   # nocov start
-  
+
   display_mode <- match.arg(display_mode)
-  
+
   if (display_mode == "long") {
-    
+
     long_report <- rep(NA_character_, length(multiagent[["agents"]]))
-    
+
     if (title == ":default:") {
       title <-
         get_default_title_text(
@@ -329,10 +329,10 @@ get_multiagent_report <- function(
           lang = lang
         )
     }
-    
+
     for (i in seq_along(multiagent[["agents"]])) {
-      
-      long_report_i <- 
+
+      long_report_i <-
         get_agent_report(
           agent = multiagent[["agents"]][[i]],
           title = if ((i != 1 || title == ":none:") && title != ":tbl_name:") {
@@ -343,7 +343,7 @@ get_multiagent_report <- function(
           lang = lang,
           locale = locale
         )
-      
+
       long_report_i <-
         long_report_i %>%
         gt::tab_options(
@@ -352,28 +352,28 @@ get_multiagent_report <- function(
           table.border.bottom.width = "6px",
           table.border.bottom.color = "#D3D3D3"
         )
-      
+
       long_report[i] <- gt::as_raw_html(long_report_i, inline_css = FALSE)
     }
-    
-    long_report <- 
+
+    long_report <-
       htmltools::tagList(
         htmltools::HTML(paste(long_report, collapse = "<br>"))
       )
-    
-    class(long_report) <- 
+
+    class(long_report) <-
       c("ptblank_multiagent_report.long", class(long_report))
-    
+
     return(long_report)
   }
 
   # Generate table type HTML
-  table_type <- 
+  table_type <-
     create_table_type_html(
       tbl_src = multiagent[["agents"]][[i]][["tbl_src"]],
       tbl_name = multiagent[["agents"]][[i]][["tbl_name"]]
     )
-  
+
   # Combine label, table type, and action levels into
   # a table subtitle <div>
   combined_subtitle <-
@@ -383,14 +383,14 @@ get_multiagent_report <- function(
           height = "25px"
         ),
         htmltools::HTML(table_type)
-      ) 
+      )
     ) %>% as.character()
 
-  
+
   create_report_time_html <- function(time) {
-    
+
     time <- Sys.time()
-    
+
     paste0(
       "<span style=\"background-color: #FFF;",
       "color: #444;padding: 0.5em 0.5em;",
@@ -401,13 +401,13 @@ get_multiagent_report <- function(
       "</span>"
     )
   }
-  
+
   # Create vector that gathers date-time values for
   # each interrogation
   date_time <- list()
-  
+
   agent_count <- length(multiagent[["agents"]])
-  
+
   if (agent_count <= 4) {
     layout_type <- "4UP"
   } else if (agent_count <= 8) {
@@ -415,46 +415,46 @@ get_multiagent_report <- function(
   } else {
     layout_type <- "16UP"
   }
-  
+
   for (i in seq_along(multiagent[["agents"]])) {
-    
+
     time_end <- gsub(" ", "\n", multiagent[["agents"]][[i]][["time_end"]])
-    
+
     i_name <- formatC(i, width = 3, flag = 0)
     i_name <- rlang::quo_name(i_name)
-    
+
     date_time_el <- list(paste0(time_end))
     names(date_time_el) <- i_name
-    
+
     date_time <- c(date_time, date_time_el)
-    
-    val_set <- 
+
+    val_set <-
       multiagent[["agents"]][[i]][["validation_set"]] %>%
       dplyr::select(
         sha1, i, eval_active, eval_error, eval_warning, all_passed,
         n, f_passed, f_failed, warn, notify, stop
       )
-    
+
     html_cells <- c()
-    
+
     for (j in seq_len(nrow(val_set))) {
-      
-      vals_step_j <- 
+
+      vals_step_j <-
         val_set %>%
         dplyr::select(-sha1) %>%
         .[j, ] %>%
         as.list()
-      
+
       cell_content <-
         generate_cell_content(
           layout_type = layout_type,
           vals_step = vals_step_j
         )
-      
+
       html_cells <- c(html_cells, cell_content)
     }
 
-    val_set <- 
+    val_set <-
       val_set %>%
       dplyr::mutate(!!i_name := html_cells) %>%
       dplyr::select(
@@ -463,25 +463,25 @@ get_multiagent_report <- function(
           n, f_passed, f_failed, warn, notify, stop
         )
       )
-    
+
     if (i == 1) {
       report_tbl <- val_set
       next
     }
-    
+
     report_tbl <-
       report_tbl %>%
       dplyr::full_join(val_set, by = "sha1")
   }
-  
+
   if (i < 4) {
     # 4UP display
     i_names <- formatC((i + 1):4, width = 3, flag = 0)
-    
+
     for (j in seq_along(i_names)) {
-      
+
       i_name <- rlang::quo_name(i_names[j])
-      
+
       report_tbl <-
         report_tbl %>%
         dplyr::bind_cols(
@@ -491,15 +491,15 @@ get_multiagent_report <- function(
     }
 
     empty_cols <- i_names
-    
+
   } else if (i > 4 && i < 8) {
     # 8UP display
     i_names <- formatC((i + 1):8, width = 3, flag = 0)
-    
+
     for (j in seq_along(i_names)) {
-      
+
       i_name <- rlang::quo_name(i_names[j])
-      
+
       report_tbl <-
         report_tbl %>%
         dplyr::bind_cols(
@@ -507,17 +507,17 @@ get_multiagent_report <- function(
         ) %>%
         dplyr::rename(!!i_name := "pb_extra_")
     }
-    
+
     empty_cols <- i_names
-    
+
   } else if (i > 8 && i < 16)  {
-    
+
     i_names <- formatC((i + 1):16, width = 3, flag = 0)
-    
+
     for (j in seq_along(i_names)) {
-      
+
       i_name <- rlang::quo_name(i_names[j])
-      
+
       report_tbl <-
         report_tbl %>%
         dplyr::bind_cols(
@@ -525,40 +525,40 @@ get_multiagent_report <- function(
         ) %>%
         dplyr::rename(!!i_name := "pb_extra_")
     }
-    
+
     empty_cols <- i_names
-    
+
   } else {
     empty_cols <- NULL
   }
 
   if (layout_type == "16UP") {
-    
-    mean_f_passed <- 
+
+    mean_f_passed <-
       vapply(
         FUN.VALUE = numeric(1),
         USE.NAMES = FALSE,
         multiagent[["agents"]],
         FUN = function(x) {
-          mean_f_passed <- 
+          mean_f_passed <-
             mean(x$validation_set$f_passed, na.rm = TRUE)
-          
+
           if (is.nan(mean_f_passed)) {
             mean_f_passed <- NA_real_
           }
-          
+
           mean_f_passed
         }
       )
-    
+
     green_vals <- floor(mean_f_passed * 255)
     red_vals <- floor((1 - mean_f_passed) * 255)
-    blue_vals <- 
+    blue_vals <-
       floor(round(1 - (abs((255 / 2) - green_vals) / (255 / 2)), 1) * 255)
-    
+
     offsets <- seq(from = 100 / i, to = 100, by = 100 / i) - ((100 / i) / 2)
-    
-    stop_tags <- 
+
+    stop_tags <-
       paste0(
         "<stop offset=\"",
         offsets, "%\" style=\"stop-color:rgb(",
@@ -567,7 +567,7 @@ get_multiagent_report <- function(
 
     gradient_line <-
       paste0(
-        "<svg height=\"10\" width=\"", 
+        "<svg height=\"10\" width=\"",
         (length(multiagent[["agents"]]) * 50) - 5, "\">\n",
         "<defs>\n",
         "<linearGradient id=\"grad1\" x1=\"0%\" y1=\"0%\" ",
@@ -575,47 +575,47 @@ get_multiagent_report <- function(
         paste(stop_tags, collapse = ""),
         "</linearGradient>\n",
         "</defs>\n",
-        "<rect x=\"0\" y=\"0\" width=\"", 
+        "<rect x=\"0\" y=\"0\" width=\"",
         (length(multiagent[["agents"]]) * 50) - 5,
         "\" height=\"10\" fill=\"url(#grad1)\" />\n",
         "</svg>"
       )
-    
+
     gradient_line <-
       paste0(
         "<div style=\"padding-bottom: 2px; overflow-x: visible;\">\n",
         gradient_line,
         "</div>"
       )
-    
+
     date_time[[1]] <- paste0(gradient_line, "\n", date_time[[1]])
   }
-  
+
   # Complete the list of column label replacements
   if (!is.null(empty_cols)) {
-    
+
     for (j in seq_along(empty_cols)) {
-      
+
       date_time_el <- list("")
       names(date_time_el) <- empty_cols[j]
-      
+
       date_time <- c(date_time, date_time_el)
     }
-    
+
   }
-    
+
   date_time <- c(list(sha1 = "STEP"), date_time)
   n_columns <- ncol(report_tbl)
   columns_used_tbl <- 1 + seq_len(i)
   columns_not_used <- setdiff(seq(2, n_columns), columns_used_tbl)
-  
+
   # Insert the icon for each step
-  assertion_tbl <- 
+  assertion_tbl <-
     dplyr::tibble(
       sha1 = character(0),
       assertion_type = character(0)
     )
-  
+
   for (x in seq_along(multiagent[["agents"]])) {
 
     assertion_tbl <-
@@ -637,7 +637,7 @@ get_multiagent_report <- function(
 
     report_tbl$sha1[x] <-
       gsub(
-        "\\s\\s+", "", 
+        "\\s\\s+", "",
         paste0(
           "<div>",
           "&nbsp;",
@@ -649,16 +649,16 @@ get_multiagent_report <- function(
         )
       )
   }
-  
+
   # Overall width should be 875px (agent report is 876px)
-  report_tbl <- 
+  report_tbl <-
     report_tbl %>%
     dplyr::select(-assertion_type) %>%
     gt::gt(id = "report")
 
   if (layout_type == "4UP") {
-    
-    report_tbl <- 
+
+    report_tbl <-
       report_tbl %>%
       gt::cols_width(
         gt::matches("[0-9]{3}") ~ gt::px(200),
@@ -684,10 +684,10 @@ get_multiagent_report <- function(
         locations = gt::cells_body(columns = gt::everything()),
         style = "height: 56px; margin: 0;"
       )
-    
+
   } else if (layout_type == "8UP") {
 
-    report_tbl <- 
+    report_tbl <-
       report_tbl %>%
       gt::cols_width(
         gt::matches("[0-9]{3}") ~ gt::px(100),
@@ -722,10 +722,10 @@ get_multiagent_report <- function(
         locations = gt::cells_body(columns = gt::everything()),
         style = "height: 56px; margin: 0;"
       )
-    
+
   } else {
-    
-    report_tbl <- 
+
+    report_tbl <-
       report_tbl %>%
       gt::cols_width(
         gt::matches("[0-9]{3}") ~ gt::px(50),
@@ -769,10 +769,10 @@ get_multiagent_report <- function(
         style = "height: 56px; margin: 0;"
       )
   }
-  
+
   if (n_columns > 17) {
-    
-    report_tbl <- 
+
+    report_tbl <-
       report_tbl %>%
       gt::tab_style(
         style = "left: 0; position: sticky; background: white; z-index: 1;",
@@ -784,17 +784,17 @@ get_multiagent_report <- function(
       ) %>%
       gt::tab_options(container.width = gt::px(875))
   }
-  
+
   # Generate the report title with the `title` option
-  title_text <- 
+  title_text <-
     process_title_text(
       title = title,
       tbl_name = NULL,
       report_type = "multiagent:wide",
       lang = lang
     )
-  
-  report_tbl <- 
+
+  report_tbl <-
     report_tbl %>%
     gt::tab_header(
       title = title_text,
@@ -809,7 +809,7 @@ get_multiagent_report <- function(
     ) %>%
     gt::fmt_markdown(columns = 2:n_columns) %>%
     gt::fmt_markdown(columns = "sha1") %>%
-    gt_missing(
+    gt::sub_missing(
       columns = columns_used_tbl,
       missing_text = gt::html(
         as.character(
@@ -824,7 +824,7 @@ get_multiagent_report <- function(
         )
       )
     ) %>%
-    gt_missing(
+    gt::sub_missing(
       columns = columns_not_used,
       missing_text = ""
     ) %>%
@@ -909,17 +909,17 @@ get_multiagent_report <- function(
 
   if (layout_type == "16UP") {
     report_tbl <-
-      report_tbl %>% 
+      report_tbl %>%
       gt::cols_label(`001` = gt::html(date_time[[2]]))
   }
-  
+
   class(report_tbl) <- c("ptblank_multiagent_report.wide", class(report_tbl))
-  
+
   # Quarto rendering workaround
   if (check_quarto()) {
     report_tbl <- gt::fmt(report_tbl, fns = identity)
   }
-  
+
   report_tbl
 }
 
@@ -943,10 +943,10 @@ generate_cell_content <- function(
   } else {
     border_indicator <- "#A5D2A5"
   }
-  
+
   if (layout_type == "4UP") {
-    
-    cell_content <- 
+
+    cell_content <-
       htmltools::tagList(
         htmltools::tags$div(
           style = htmltools::css(
@@ -1197,18 +1197,18 @@ generate_cell_content <- function(
             )
           )
         )
-      ) %>% 
+      ) %>%
       as.character()
-    
-    return(cell_content) 
+
+    return(cell_content)
   }
-  
+
   if (layout_type == "8UP") {
 
     if (border_indicator == "transparent") {
       border_indicator <- "#FD9893"
     }
-    
+
     if (!vals_step$eval_active) {
       background_color <- "#F5F5F5"
     } else if (vals_step$eval_error) {
@@ -1219,7 +1219,7 @@ generate_cell_content <- function(
       background_color <- "none"
     }
 
-    cell_content <- 
+    cell_content <-
       htmltools::tagList(
         htmltools::tags$div(
           style = htmltools::css(
@@ -1393,19 +1393,19 @@ generate_cell_content <- function(
             )
           )
         )
-      ) %>% 
+      ) %>%
       as.character()
-    
+
     return(cell_content)
   }
-  
+
   if (layout_type == "16UP") {
 
     if (border_indicator == "transparent") {
       border_indicator <- "#FD9893"
     }
-    
-    cell_content <- 
+
+    cell_content <-
       htmltools::tagList(
           htmltools::tags$div(
             style = htmltools::css(
@@ -1458,46 +1458,46 @@ generate_cell_content <- function(
                   "<rect x=\"1.25\" y=\"0\" height=\"10\" width=\"14\"",
                   "style=\"stroke: ",
                   ifelse(
-                    is.na(vals_step$warn), 
+                    is.na(vals_step$warn),
                     "#E5E5E5;",
                     "#F2AA3B;" # color: Tulip Tree
-                  ), 
+                  ),
                   "fill: ",
                   ifelse(
-                    !is.na(vals_step$warn) && vals_step$warn, 
+                    !is.na(vals_step$warn) && vals_step$warn,
                     "#F7CC89;",
                     "none;"
-                  ), 
+                  ),
                   "stroke-width: 1.5;\">",
                   "</rect>",
                   "<rect x=\"17.25\" y=\"0\" height=\"10\" width=\"14\"",
                   "style=\"stroke: ",
                   ifelse(
-                    is.na(vals_step$stop), 
+                    is.na(vals_step$stop),
                     "#E5E5E5;",
                     "#CE5B4D;" # color: Valencia
                   ),
                   "fill: ",
                   ifelse(
-                    !is.na(vals_step$stop) && vals_step$stop, 
+                    !is.na(vals_step$stop) && vals_step$stop,
                     "#E19C94;",
                     "none;"
-                  ), 
+                  ),
                   "stroke-width: 1.5;\">",
                   "</rect>",
                   "<rect x=\"33.25\" y=\"0\" height=\"10\" width=\"14\"",
                   "style=\"stroke: ",
                   ifelse(
-                    is.na(vals_step$notify), 
+                    is.na(vals_step$notify),
                     "#E5E5E5;",
                     "#52ACE6;" # color: Picton Blue
                   ),
                   "fill: ",
                   ifelse(
-                    !is.na(vals_step$notify) && vals_step$notify, 
+                    !is.na(vals_step$notify) && vals_step$notify,
                     "#97CDF0;",
                     "none;"
-                  ), 
+                  ),
                   "stroke-width: 1.5;\">",
                   "</rect>",
                   "</svg>"
@@ -1505,9 +1505,9 @@ generate_cell_content <- function(
               )
             )
           )
-      ) %>% 
+      ) %>%
       as.character()
-    
+
     return(cell_content)
   }
   NULL
