@@ -1,28 +1,28 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
 #' Are row data complete?
 #'
 #' @description
-#' 
+#'
 #' The `rows_complete()` validation function, the `expect_rows_complete()`
 #' expectation function, and the `test_rows_complete()` test function all check
 #' whether rows contain any `NA`/`NULL` values (optionally constrained to a
@@ -32,28 +32,28 @@
 #' be used with a data table. As a validation step or as an expectation, this
 #' will operate over the number of test units that is equal to the number of
 #' rows in the table (after any `preconditions` have been applied).
-#' 
+#'
 #' @param columns *The target columns*
-#' 
+#'
 #'   `<tidy-select>` // *default:* `everything()`
-#' 
+#'
 #'   A column-selecting expression, as one would use inside `dplyr::select()`.
 #'   Specifies the set of column(s) for which the completeness of rows is
 #'   checked.
-#' 
+#'
 #' @inheritParams col_vals_gt
-#'   
+#'
 #' @return For the validation function, the return value is either a
 #'   `ptblank_agent` object or a table object (depending on whether an agent
 #'   object or a table was passed to `x`). The expectation function invisibly
 #'   returns its input but, in the context of testing data, the function is
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
-#' 
+#'
 #' @section Supported Input Tables:
-#' 
+#'
 #' The types of data tables that are officially supported are:
-#' 
+#'
 #'  - data frames (`data.frame`) and tibbles (`tbl_df`)
 #'  - Spark DataFrames (`tbl_spark`)
 #'  - the following database tables (`tbl_dbi`):
@@ -63,13 +63,13 @@
 #'    - *BigQuery* tables (using `bigrquery::bigquery()`)
 #'    - *DuckDB* tables (through `duckdb::duckdb()`)
 #'    - *SQLite* (with `RSQLite::SQLite()`)
-#'    
+#'
 #' Other database tables may work to varying degrees but they haven't been
 #' formally tested (so be mindful of this when using unsupported backends with
 #' **pointblank**).
-#' 
+#'
 #' @section Preconditions:
-#' 
+#'
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
 #' the target table during interrogation as a preparatory step. It might happen
 #' that a particular validation requires a calculated column, some filtering of
@@ -86,16 +86,16 @@
 #' serves as the input data table to be transformed (e.g., `~ . %>%
 #' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
 #' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
-#' 
+#'
 #' @section Segments:
-#' 
+#'
 #' By using the `segments` argument, it's possible to define a particular
 #' validation with segments (or row slices) of the target table. An optional
 #' expression or set of expressions that serve to segment the target table by
 #' column values. Each expression can be given in one of two ways: (1) as column
 #' names, or (2) as a two-sided formula where the LHS holds a column name and
 #' the RHS contains the column values to segment on.
-#' 
+#'
 #' As an example of the first type of expression that can be used,
 #' `vars(a_column)` will segment the target table in however many unique values
 #' are present in the column called `a_column`. This is great if every unique
@@ -114,9 +114,9 @@
 #' combo, it's possible to generate labels for segmentation using an expression
 #' for `preconditions` and refer to those labels in `segments` without having to
 #' generate a separate version of the target table.
-#' 
+#'
 #' @section Actions:
-#' 
+#'
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list object
 #' that is best produced by the [action_levels()] function. Read that function's
@@ -129,31 +129,31 @@
 #' 0.25)` are good choices depending on the situation (the first produces a
 #' warning when a quarter of the total test units fails, the other `stop()`s at
 #' the same threshold level).
-#' 
+#'
 #' @section Labels:
-#' 
+#'
 #' `label` may be a single string or a character vector that matches the number
 #' of expanded steps. `label` also supports `{glue}` syntax and exposes the
 #' following dynamic variables contextualized to the current step:
-#'   
+#'
 #' - `"{.step}"`: The validation step name
 #' - `"{.col}"`: The current column name
 #' - `"{.seg_col}"`: The current segment's column name
 #' - `"{.seg_val}"`: The current segment's value/group
-#'     
+#'
 #' The glue context also supports ordinary expressions for further flexibility
 #' (e.g., `"{toupper(.step)}"`) as long as they return a length-1 string.
-#' 
+#'
 #' @section Briefs:
-#' 
+#'
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
-#' 
+#'
 #' @section YAML:
-#' 
+#'
 #' A **pointblank** agent can be written to YAML with [yaml_write()] and the
 #' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
 #' or interrogate the target table (via [yaml_agent_interrogate()]). When
@@ -162,11 +162,11 @@
 #' function. Here is an example of how a complex call of `rows_complete()` as a
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
-#' 
+#'
 #' R statement:
-#' 
+#'
 #' ```r
-#' agent %>% 
+#' agent %>%
 #'   rows_complete(
 #'     columns = c(a, b),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
@@ -176,9 +176,9 @@
 #'     active = FALSE
 #'   )
 #' ```
-#' 
+#'
 #' YAML representation:
-#' 
+#'
 #' ```yaml
 #' steps:
 #' - rows_complete:
@@ -191,7 +191,7 @@
 #'     label: The `rows_complete()` step.
 #'     active: false
 #' ```
-#' 
+#'
 #' In practice, both of these will often be shorter. A value for `columns` is
 #' only necessary if checking for unique values across a subset of columns.
 #' Arguments with default values won't be written to YAML when using
@@ -199,11 +199,11 @@
 #' when generating the YAML by other means). It is also possible to preview the
 #' transformation of an agent to YAML without any writing to disk by using the
 #' [yaml_agent_string()] function.
-#'   
+#'
 #' @section Examples:
-#' 
+#'
 #' Create a simple table with three columns of numerical values.
-#' 
+#'
 #' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
@@ -211,66 +211,66 @@
 #'     b = c(7, 1, 0, 0, 8, 3),
 #'     c = c(1, 1, 1, 3, 3, 3)
 #'   )
-#' 
+#'
 #' tbl
 #' ```
-#' 
+#'
 #' ## A: Using an `agent` with validation functions and then `interrogate()`
-#' 
+#'
 #' Validate that when considering only data in columns `a` and `b`, there are
 #' only complete rows (i.e., all rows have no `NA` values).
-#' 
+#'
 #' ```r
 #' agent <-
 #'   create_agent(tbl = tbl) %>%
 #'   rows_complete(columns = c(a, b)) %>%
 #'   interrogate()
 #' ```
-#' 
+#'
 #' Printing the `agent` in the console shows the validation report in the
 #' Viewer. Here is an excerpt of validation report, showing the single entry
 #' that corresponds to the validation step demonstrated here.
-#' 
+#'
 #' \if{html}{
 #' \out{
 #' `r pb_get_image_tag(file = "man_rows_complete_1.png")`
 #' }
 #' }
-#' 
+#'
 #' ## B: Using the validation function directly on the data (no `agent`)
-#' 
+#'
 #' This way of using validation functions acts as a data filter. Data is passed
 #' through but should `stop()` if there is a single test unit failing. The
 #' behavior of side effects can be customized with the `actions` option.
-#' 
+#'
 #' ```{r}
 #' tbl %>%
 #'   rows_complete(columns = c(a, b)) %>%
 #'   dplyr::pull(a)
 #' ```
-#' 
+#'
 #' ## C: Using the expectation function
-#' 
+#'
 #' With the `expect_*()` form, we would typically perform one validation at a
 #' time. This is primarily used in **testthat** tests.
-#' 
+#'
 #' ```r
 #' expect_rows_complete(tbl, columns = c(a, b))
 #' ```
-#' 
+#'
 #' ## D: Using the test function
-#' 
+#'
 #' With the `test_*()` form, we should get a single logical value returned to
 #' us.
-#' 
+#'
 #' ```{r}
 #' test_rows_complete(tbl, columns = c(a, b))
 #' ```
-#' 
+#'
 #' @family validation functions
 #' @section Function ID:
 #' 2-21
-#' 
+#'
 #' @name rows_complete
 NULL
 
@@ -288,7 +288,7 @@ rows_complete <- function(
     brief = NULL,
     active = TRUE
 ) {
-  
+
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
   # `rows_*()` functions treat `NULL` as `everything()`
@@ -297,10 +297,10 @@ rows_complete <- function(
   }
   # Get `columns` as a label
   columns_expr <- as_columns_expr(columns)
-  
+
   # Resolve the columns based on the expression
   columns <- resolve_columns(x = x, var_expr = columns, preconditions = NULL)
-  
+
   # Resolve segments into list
   segments_list <-
     resolve_segments(
@@ -308,10 +308,10 @@ rows_complete <- function(
       seg_expr = segments,
       preconditions = preconditions
     )
-  
+
   if (is_a_table_object(x)) {
-    
-    secret_agent <- 
+
+    secret_agent <-
       create_agent(x, label = "::QUIET::") %>%
       rows_complete(
         columns = tidyselect::all_of(columns),
@@ -323,44 +323,41 @@ rows_complete <- function(
         active = active
       ) %>%
       interrogate()
-    
+
     return(x)
   }
-  
+
   agent <- x
-  
+
   if (length(columns) > 1) {
     columns <- paste(columns, collapse = ", ")
   }
-  
-  if (is.null(brief)) {
-    
-    brief <-
-      create_autobrief(
-        agent = agent,
-        assertion_type = "rows_complete",
-        column = columns
-      )
-  }
-  
+
+  brief <- resolve_brief(
+    brief = brief, agent = agent,
+    columns = columns, segments_list = segments_list,
+    preconditions = preconditions,
+    assertion_type = "rows_complete"
+  )
+
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns = "column", agent)
-  
+
   # Get the next step number for the `validation_set` tibble
   i_o <- get_next_validation_set_row(agent)
-  
+
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
-  
+
   # Add one or more validation steps based on the
   # length of `segments`
   label <- resolve_label(label, segments = segments_list)
   for (i in seq_along(segments_list)) {
-    
+
     seg_col <- names(segments_list[i])
     seg_val <- unname(unlist(segments_list[i]))
-    
+
     agent <-
       create_validation_step(
         agent = agent,
@@ -376,11 +373,11 @@ rows_complete <- function(
         actions = covert_actions(actions, agent),
         step_id = step_id,
         label = label[[i]],
-        brief = brief,
+        brief = brief[[i]],
         active = active
       )
   }
-  
+
   agent
 }
 
@@ -393,10 +390,10 @@ expect_rows_complete <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
+
   fn_name <- "expect_rows_complete"
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     rows_complete(
       columns = {{ columns }},
@@ -405,26 +402,26 @@ expect_rows_complete <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   x <- vs$notify %>% all()
-  
+
   threshold_type <- get_threshold_type(threshold = threshold)
-  
+
   if (threshold_type == "proportional") {
     failed_amount <- vs$f_failed
   } else {
     failed_amount <- vs$n_failed
   }
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   act <- testthat::quasi_label(enquo(x), arg = "object")
-  
+
   testthat::expect(
     ok = identical(!as.vector(act$val), TRUE),
     failure_message = glue::glue(
@@ -433,9 +430,9 @@ expect_rows_complete <- function(
       )
     )
   )
-  
+
   act$val <- object
-  
+
   invisible(act$val)
 }
 
@@ -448,8 +445,8 @@ test_rows_complete <- function(
     preconditions = NULL,
     threshold = 1
 ) {
-  
-  vs <- 
+
+  vs <-
     create_agent(tbl = object, label = "::QUIET::") %>%
     rows_complete(
       columns = {{ columns }},
@@ -458,13 +455,13 @@ test_rows_complete <- function(
     ) %>%
     interrogate() %>%
     .$validation_set
-  
+
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
   if (inherits(vs$capture_stack[[1]]$error, "simpleError")) {
     stop(conditionMessage(vs$capture_stack[[1]]$error))
   }
-  
+
   all(!vs$notify)
 }
