@@ -1,21 +1,21 @@
 #------------------------------------------------------------------------------#
-# 
-#                 _         _    _      _                _    
-#                (_)       | |  | |    | |              | |   
+#
+#                 _         _    _      _                _
+#                (_)       | |  | |    | |              | |
 #   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
 #  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   <
 #  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-#  | |                                                        
-#  |_|                                                        
-#  
+#  | |
+#  |_|
+#
 #  This file is part of the 'rstudio/pointblank' project.
-#  
-#  Copyright (c) 2017-2024 pointblank authors
-#  
+#
+#  Copyright (c) 2017-2025 pointblank authors
+#
 #  For full copyright and license information, please look at
 #  https://rstudio.github.io/pointblank/LICENSE.html
-# 
+#
 #------------------------------------------------------------------------------#
 
 
@@ -36,19 +36,19 @@ has_agent_intel <- function(agent) {
 }
 
 get_tbl_object <- function(agent) {
-  
+
   if (!is.null(agent$tbl)) {
-    
+
     tbl <- agent$tbl
-    
+
   } else if (!is.null(agent$read_fn)) {
-    
+
     tbl <- materialize_table(agent$read_fn)
-    
+
   } else {
     tbl <- NULL
   }
-  
+
   tbl
 }
 
@@ -79,11 +79,11 @@ is_arrow_object <- function(x) {
 }
 
 is_tbl_mssql <- function(x) {
-  
+
   if (!is_tbl_dbi(x)) {
     return(FALSE)
-  } 
-  
+  }
+
   tbl_src_details <- tolower(get_tbl_dbi_src_details(x))
   grepl("sql server|sqlserver", tbl_src_details)
 }
@@ -92,16 +92,16 @@ is_tbl_mssql <- function(x) {
 
 # Generate a label for the `agent` or `informant` object
 generate_label <- function(label = NULL) {
-  
+
   if (!is.null(label)) return(as.character(label))
-  
+
   paste0("[", gsub(" ", "|", strftime(Sys.time())), "]")
 }
 
 safely_transformer <- function(otherwise = NA) {
-  
+
   oth <- otherwise
-  
+
   function(text, envir) {
     tryCatch(
       eval(parse(text = text, keep.source = FALSE), envir),
@@ -114,7 +114,7 @@ glue_safely <- function(
     .otherwise = NA,
     .envir = parent.frame()
 ) {
-  
+
   as.character(
     glue::glue(
       ...,
@@ -139,7 +139,7 @@ number_of_validation_steps <- function(agent) {
 
 # Get the next step number for the `validation_set` tibble
 get_next_validation_set_row <- function(agent) {
-  
+
   if (nrow(agent$validation_set) == 0) {
     step <- 1L
   } else {
@@ -165,10 +165,10 @@ get_column_as_sym_at_idx <- function(agent, idx) {
 }
 
 get_values_at_idx <- function(agent, idx) {
-  
+
   # Get list-column element (`values` is always a length-1 list)
   values <- agent$validation_set[[idx, "values"]]
-  
+
   # Expressions (via `col_vals_expr()`) and functions (via `specially()`)
   # can get the old `unlist()` treatment
   if (rlang::is_expression(values[[1]]) || rlang::is_function(values[[1]])) {
@@ -178,7 +178,7 @@ get_values_at_idx <- function(agent, idx) {
     # to preserve class
     values <- values[[1]]
   }
-  
+
   values
 }
 
@@ -191,40 +191,43 @@ get_all_cols <- function(agent) {
 }
 
 materialize_table <- function(tbl, check = TRUE) {
-  
+
   if (is.null(tbl)) {
     stop("A table must be provided.", call. = FALSE)
   }
-  
+
   if (is_a_table_object(tbl)) {
     return(tbl)
   } else if (inherits(tbl, "function")) {
     tbl <- rlang::exec(tbl)
   } else if (rlang::is_formula(tbl)) {
-    
-    tbl <- tbl %>% rlang::f_rhs() %>% rlang::eval_tidy()
-    
+    tbl <- eval_f_rhs(tbl)
     if (inherits(tbl, "read_fn")) {
-      tbl <- tbl %>% rlang::f_rhs() %>% rlang::eval_tidy()
+      tbl <- eval_f_rhs(tbl)
     }
-    
   } else {
-    
-    stop(
-      "The `tbl` object must either be a table, a function, or a formula.\n",
-      "* A table-prep formula can be used (with the expression on the RHS).\n",
-      "* A function can be made with `function()` {<tbl reading code>}.",
-      call. = FALSE
-    )
-  }  
-  
-  if (check) {
-    is_a_table_object(tbl)
+    err_not_table_object()
   }
-  
+
+  if (check && !is_a_table_object(tbl)) {
+    err_not_table_object()
+  }
+
   tbl
 }
 
+err_not_table_object <- function() {
+  cli::cli_abort(c(
+    "x" = "The agent `tbl` must either be a table, a function, or a formula",
+    "i" = "A table-prep formula can be made with expression on the RHS",
+    "i" = "A function can be made with `function() {{<tbl reading code>}}`"
+  ), call = NULL)
+}
+
+eval_f_rhs <- function(f) {
+  eval(rlang::f_rhs(f), rlang::f_env(f))
+}
+
 as_columns_expr <- function(columns) {
   columns_expr <- gsub("^\"|\"$", "", rlang::as_label(columns))
   # Treat NULL and missing `columns` as the same
@@ -238,7 +241,43 @@ is_secret_agent <- function(x) {
   is_ptblank_agent(x) && (x$label == "::QUIET::")
 }
 
-resolve_label <- function(label, columns = "", segments = "") {
+resolve_brief <- function(brief, agent,
+                          columns = list(NULL), segments_list = list(NULL),
+                          preconditions = NULL, values = NULL,
+                          assertion_type) {
+
+  n_columns <- length(columns)
+  n_segments <- length(segments_list)
+  n_combinations <- n_columns * n_segments
+
+  # If missing, apply auto-brief
+  if (is.null(brief)) {
+    brief <- generate_autobriefs(
+      agent = agent, columns = columns,
+      preconditions = preconditions, values = values,
+      assertion_type = assertion_type
+    )
+    # auto-brief is generated once per column - need to recycle by segment
+    brief <- rep(brief, each = n_segments)
+  }
+
+  # Brief must be a single string or matched in length
+  if (!length(brief) %in% c(1L, n_combinations)) {
+    cli::cli_abort(paste0(
+      "`brief` must be length 1",
+      if (n_combinations != 1L) " or {n_combinations}",
+      ", not {length(brief)}."
+    ))
+  }
+
+  # Recycle the string
+  brief <- rep_len(brief, n_combinations)
+  # Return packed vector/matrix for iteration over steps
+  pack_by_col_seg(brief, n_columns, n_segments,  c(columns, segments))
+
+}
+
+resolve_label <- function(label, columns = list(NULL), segments = list(NULL)) {
   n_columns <- length(columns)
   n_segments <- length(segments)
   n_combinations <- n_columns * n_segments
@@ -246,42 +285,48 @@ resolve_label <- function(label, columns = "", segments = "") {
   if (is.null(label)) {
     label <- NA_character_
   }
-  # If length-1, match length of col-x-seg combination
-  if (length(label) == 1) {
-    label <- rep_len(label, n_combinations)
+  # Label must be a single string or matched in length
+  if (!length(label) %in% c(1L, n_combinations)) {
+    cli::cli_abort(paste0(
+      "`label` must be length 1",
+      if (n_combinations != 1L) " or {n_combinations}",
+      ", not {length(label)}."
+    ))
   }
-  # Check for length match
-  if (length(label) != n_combinations) {
-    rlang::abort(paste0("`label` must be length 1 or ", n_combinations,
-                        ", not ", length(label)))
-  }
-  # Create a columns * segments matrix of the (recycled) label vector
-  # - Fill by row to preserve order (for loops iterate the j before the i)
-  out <- matrix(label, nrow = n_columns, ncol = n_segments, byrow = TRUE)
+  # Recycle the string
+  label <- rep_len(label, n_combinations)
+  # Return packed vector/matrix for iteration over steps
+  pack_by_col_seg(label, n_columns, n_segments, c(columns, segments))
+}
+
+# Create a columns * segments matrix/vector for an input (ex: `brief`, `label`)
+# - Subsettable via `out[col]`, `out[seg]`, or `out[col,seg]`
+pack_by_col_seg <- function(x, n_columns, n_segments, packed_dim) {
+  # Fill by row to preserve order (for loops iterate the j before the i)
+  out <- matrix(x, nrow = n_columns, ncol = n_segments, byrow = TRUE)
   # If missing columns and/or segments, collapse to vector/scalar
-  if (missing(columns) || missing(segments)) {
+  if (any(lengths(packed_dim) == 0)) {
     out <- as.vector(out)
   }
-  # A matrix/vector subsettable via `out[col]`, `out[seg]`, or `out[col,seg]`
   out
 }
 
 #' The `resolve_segments()` function works with input from the `segments`
 #' argument, present is a variety of row-based validation functions.
-#' 
+#'
 #' @return A segment list with <column_name> = <column_value>
 #' @noRd
 resolve_segments <- function(x, seg_expr, preconditions) {
-  
+
   # Return a list with an NA_character_ vector if the `seg_expr` is NULL
   if (is.null(seg_expr)) {
-    
+
     empty_vec <- c("empty" = NA_character_)
     names(empty_vec) <- NA_character_
-    
+
     return(as.list(empty_vec))
   }
-  
+
   # Upgrade single item to a list
   if (
     rlang::is_formula(seg_expr) ||
@@ -289,7 +334,7 @@ resolve_segments <- function(x, seg_expr, preconditions) {
   ) {
     seg_expr <- list(seg_expr)
   }
-  
+
   # Verify that `seg_expr` is a list
   if (!is.list(seg_expr)) {
     stop(
@@ -297,44 +342,44 @@ resolve_segments <- function(x, seg_expr, preconditions) {
       call. = FALSE
     )
   }
-  
+
   segments_list <- list()
-  
+
   # Process each `seg_expr` element
   for (i in seq_along(seg_expr)) {
-    
+
     if (inherits(seg_expr[[i]], "quosures")) {
-      
+
       if (inherits(x, c("data.frame", "tbl_df", "tbl_dbi"))) {
         tbl <- x
       } else if (inherits(x, ("ptblank_agent"))) {
         tbl <- get_tbl_object(agent = x)
       }
-      
+
       if (!is.null(preconditions)) {
         tbl <- apply_preconditions(tbl = tbl, preconditions = preconditions)
       }
-      
+
       for (j in seq_along(seg_expr[[i]])) {
-        
+
         column_name <- rlang::as_label(seg_expr[[i]][[j]])
-        
-        col_seg_vals <- 
+
+        col_seg_vals <-
           tbl %>%
           dplyr::select(tidyselect::all_of(column_name)) %>%
           dplyr::distinct() %>%
           dplyr::pull()
-        
+
         names(col_seg_vals) <- rep(column_name, length(col_seg_vals))
-        
+
         segments_list <- c(segments_list, as.list(col_seg_vals))
       }
     }
-    
+
     if (rlang::is_formula(seg_expr[[i]])) {
-  
+
       group_formula <- seg_expr[[i]]
-      
+
       # Determine if this is a two-sided formula
       if (
         is.null(rlang::f_lhs(group_formula)) ||
@@ -345,21 +390,21 @@ resolve_segments <- function(x, seg_expr, preconditions) {
           call. = FALSE
         )
       }
-      
+
       col_seg_vals <- rlang::eval_bare(rlang::f_rhs(group_formula))
-      
+
       column_name <- rlang::as_label(rlang::f_lhs(group_formula))
-      
+
       if (grepl("^vars\\(.+\\)$", column_name)) {
         column_name <- gsub("(vars\\(|\\))", "", column_name)
       }
-      
+
       names(col_seg_vals) <- rep(column_name, length(col_seg_vals))
-      
+
       segments_list <- c(segments_list, as.list(col_seg_vals))
     }
   }
-  
+
   segments_list
 }
 
@@ -372,20 +417,20 @@ normalize_step_id <- function(step_id, columns, agent) {
     } else {
       i <- max(agent$validation_set$i) + 1
     }
-    
+
     steps <- length(columns) - 1
     i <- seq(from = i, to = i + steps)
-    
+
     # Generate an ID based on `i`
     step_id <- formatC(i, width = 4, format = "d", flag = "0")
     return(step_id)
   }
-  
+
   # Ensure that `step_id` is coerced to character
   step_id <- as.character(step_id)
-  
+
   if (length(columns) == 1) {
-    
+
     if (length(step_id) > 1) {
       warning(
         "Multiple `step_id` values provided for a single column:\n",
@@ -393,32 +438,32 @@ normalize_step_id <- function(step_id, columns, agent) {
         call. = FALSE
       )
     }
-    
+
     return(step_id[1])
-    
+
   } else if (length(columns) > 1) {
-    
+
     if (length(step_id) == length(columns)) {
-      
+
      if (anyDuplicated(step_id) != 0) {
-       
+
        # Issue warning about duplicated `step_id` values
        warning(
          "Duplicate `step_id` values provided:\n",
          "* Only the first `step_id` element will be used.",
          call. = FALSE
        )
-       
+
        step_id <- generate_indexed_vals(step_id[1], seq_along(columns))
      }
-    
+
       return(step_id)
-      
+
     } else if (length(step_id) == 1) {
-      
+
       # Generate multiple `step_id` values with single `step_id`
       step_id <- generate_indexed_vals(step_id[1], seq_along(columns))
-      
+
     } else if (length(step_id) != 1 && length(step_id) != length(columns)) {
 
       # Issue warning about length of `step_id`
@@ -428,21 +473,21 @@ normalize_step_id <- function(step_id, columns, agent) {
         "* Only the first `step_id` element will be used.",
         call. = FALSE
       )
-      
+
       step_id <- generate_indexed_vals(step_id[1], seq_along(columns))
     }
   }
-  
+
   step_id
 }
 
 check_step_id_duplicates <- function(step_id, agent) {
-  
+
   if (any(step_id %in% agent$validation_set$step_id)) {
 
     error_at_index <- max(agent$validation_set$i)
     a_duplicate_step_id <- step_id[step_id %in% agent$validation_set$step_id][1]
-    
+
     stop(
       "Just after step index `", error_at_index,
       "`, the following `step_id` has been ",
@@ -456,7 +501,7 @@ check_step_id_duplicates <- function(step_id, agent) {
 check_is_a_table_object <- function(tbl) {
 
   if (!is_a_table_object(tbl)) {
-    
+
     stop(
       "The object supplied is not a table object, valid tables are:\n",
       "* data frames, tibbles, or data.table objects\n",
@@ -471,9 +516,9 @@ check_is_a_table_object <- function(tbl) {
 # A portion of this is dedicated to checking the `read_fn` argument which
 # is undergoing soft deprecation in `create_agent()` and `create_informant()`
 check_table_input <- function(tbl, read_fn) {
-  
+
   if (is.null(tbl) && is.null(read_fn)) {
-    
+
     stop(
       "The `tbl` argument requires a table, this could either be:\n",
       " * An in-memory table, a database table, or a Spark table\n",
@@ -482,9 +527,9 @@ check_table_input <- function(tbl, read_fn) {
       call. = FALSE
     )
   }
-  
+
   if (!is.null(read_fn)) {
-    
+
     warning(
       "Use `tbl` to specify a target table (`read_fn` is now undergoing ",
       "deprecation):\n",
@@ -493,7 +538,7 @@ check_table_input <- function(tbl, read_fn) {
       " * A table can be supplied directly to `tbl` (as before)\n",
       call. = FALSE
     )
-    
+
     if (!is.null(tbl)) {
       message(
         "The value supplied to `read_fn` has ignored since `tbl` ",
@@ -503,38 +548,38 @@ check_table_input <- function(tbl, read_fn) {
       tbl <- read_fn
     }
   }
-  
+
   tbl
 }
 
 process_table_input <- function(tbl, tbl_name) {
-  
+
   if (inherits(tbl, "function")) {
-    
+
     read_fn <- tbl
     tbl <- NULL
-    
+
   } else if (rlang::is_formula(tbl)) {
-    
+
     read_fn <- tbl
     tbl <- NULL
-    
+
     if (inherits(read_fn, "read_fn")) {
-      
+
       if (inherits(read_fn, "with_tbl_name") && is.na(tbl_name)) {
         tbl_name <- read_fn %>% rlang::f_lhs() %>% as.character()
       }
     }
-    
+
   } else {
     read_fn <- NULL
   }
-  
+
   # Remove grouping for data frames or tibbles
   if (is_tbl_df(tbl) && dplyr::is_grouped_df(tbl)) {
     tbl <- dplyr::ungroup(tbl)
   }
-  
+
   list(
     tbl = tbl,
     read_fn = read_fn,
@@ -547,7 +592,7 @@ generate_indexed_vals <- function(x, numbers, sep = ".") {
 }
 
 get_threshold_type <- function(threshold) {
-  
+
   if (threshold >= 1) {
     threshold_type <- "absolute"
   } else if (threshold >= 0 && threshold < 1) {
@@ -562,10 +607,10 @@ all_data_vars <- function(x, data_cols) {
   reparsed <- parse(text = deparsed, keep.source = TRUE)
   x <- utils::getParseData(reparsed)
   if (is.null(x)) return(NA_character_)
-  
+
   .data_vars <- pronoun_vars(x, ".data")
   .env_vars <- pronoun_vars(x, ".env")
-  
+
   bare_syms <- x[
     x$token == "SYMBOL" &
       !x$text %in% c(".data", ".env") &
@@ -581,15 +626,15 @@ all_data_vars <- function(x, data_cols) {
     all_cols <- all_cols[order(as.integer(names(all_cols)))]
     all_cols <- unique(all_cols)
   }
-  
+
   all_cols <- all_cols[all_cols %in% data_cols]
-  
+
   if (length(all_cols) == 0) {
     NA_character_
   } else {
     sort(all_cols)
   }
-  
+
 }
 
 pronoun_vars <- function(x, pronoun = c(".data", ".env")) {
@@ -614,7 +659,7 @@ pronoun_vars <- function(x, pronoun = c(".data", ".env")) {
 # nocov end
 
 all_validations_fns_vec <- function() {
-  
+
   c(
     "col_vals_lt",
     "col_vals_lte",
@@ -656,7 +701,7 @@ all_validations_fns_vec <- function() {
 }
 
 row_based_validation_fns_vec <- function() {
-  
+
   c(
     "col_vals_lt",
     "col_vals_lte",
@@ -684,7 +729,7 @@ row_based_validation_fns_vec <- function() {
 }
 
 column_expansion_fns_vec <- function() {
-  
+
   c(
     "col_vals_lt",
     "col_vals_lte",
@@ -725,7 +770,7 @@ get_tbl_dbi_src_details <- function(tbl) {
 }
 
 get_r_column_names_types <- function(tbl) {
-  
+
   suppressWarnings(
     column_header <-
       tbl %>%
@@ -734,7 +779,7 @@ get_r_column_names_types <- function(tbl) {
   )
   column_names_types <-
     vapply(column_header, function(x) class(x)[1], character(1))
-  
+
   list(
     col_names = names(column_names_types),
     r_col_types = unname(unlist(column_names_types)),
@@ -743,50 +788,50 @@ get_r_column_names_types <- function(tbl) {
 }
 
 get_tbl_information <- function(tbl) {
-  
+
   if (is.data.frame(tbl)) {
-    
+
     tbl_information <- get_tbl_information_df(tbl)
-    
+
   } else if (is_tbl_spark(tbl)) {
-    
+
     # nocov start
-    
+
     tbl_information <- get_tbl_information_spark(tbl)
-    
+
     # nocov end
-    
+
   } else if (is_tbl_dbi(tbl)) {
-    
+
     tbl_information <- get_tbl_information_dbi(tbl)
-    
+
   } else if (is_arrow_object(tbl)) {
-    
+
     # nocov start
 
     tbl_information <- get_tbl_information_arrow(tbl)
-    
+
     # nocov end
-    
+
   } else {
-    
+
     # nocov start
-    
+
     warning("Information on this table type cannot be obtained at present.",
             call. = FALSE)
-    
+
     # nocov end
-  } 
-  
+  }
+
   tbl_information
 }
 
 get_tbl_information_df <- function(tbl) {
-  
+
   r_column_names_types <- get_r_column_names_types(tbl)
-  
+
   tbl_src <- if (tibble::is_tibble(tbl)) "tbl_df" else "data.frame"
-  
+
   list(
     tbl_src = tbl_src,
     tbl_src_details = NA_character_,
@@ -801,17 +846,17 @@ get_tbl_information_df <- function(tbl) {
 # nocov start
 
 get_tbl_information_spark <- function(tbl) {
-  
+
   r_column_names_types <- get_r_column_names_types(tbl)
-  
+
   tbl_schema <- sparklyr::sdf_schema(tbl)
-  
-  db_col_types <- 
+
+  db_col_types <-
     lapply(tbl_schema, `[[`, 2) %>%
     unlist() %>%
     unname() %>%
     tolower()
-  
+
   list(
     tbl_src = "tbl_spark",
     tbl_src_details = "Spark",
@@ -830,43 +875,49 @@ get_tbl_information_dbi <- function(tbl) {
   tbl_connection <- tbl$src$con
 
   tbl_src_details <- tolower(get_tbl_dbi_src_details(tbl))
-  
+
   if (grepl("sql server|sqlserver", tbl_src_details)) {
-    
+
     # nocov start
     tbl_src <- "mssql"
     # nocov end
-    
+
   } else if (grepl("duckdb", tbl_src_details)) {
-    
+
     # nocov start
     tbl_src <- "duckdb"
     # nocov end
-      
+
   } else if (grepl("bq_|bigquery", tbl_src_details)) {
-      
+
     # nocov start
     tbl_src <- "bigquery"
     # nocov end
-      
-  } else {
-    tbl_src <- gsub("^([a-z]*).*", "\\1", get_tbl_dbi_src_details(tbl))
-  }
-  
-  db_tbl_name <- as.character(dbplyr::remote_name(tbl))
-  
-  r_column_names_types <- get_r_column_names_types(tbl)
-  
-  n_cols <- length(r_column_names_types$col_names)
-  
-  # nolint start
-  
-  if (tbl_src == "postgres") {
-    
+
+  } else if (grepl("oracle", tbl_src_details)) {
+
     # nocov start
-    
+    tbl_src <- "oracle"
+    # nocov end
+
+  } else {
+    tbl_src <- gsub("^([a-z]*).*", "\\1", tbl_src_details)
+  }
+
+  db_tbl_name <- as.character(dbplyr::remote_name(tbl))
+
+  r_column_names_types <- get_r_column_names_types(tbl)
+
+  n_cols <- length(r_column_names_types$col_names)
+
+  # nolint start
+
+  if (tbl_src == "postgres") {
+
+    # nocov start
+
     db_tbl_name_no_schema <- gsub(".*\\.", "", db_tbl_name)
-    
+
     q_types <-
       as.character(
         glue::glue(
@@ -875,23 +926,23 @@ get_tbl_information_dbi <- function(tbl) {
         table_name = '{db_tbl_name_no_schema}'"
         )
       )
-    
+
     # nocov end
-    
+
   } else if (tbl_src == "bigquery") {
-    
+
     # nocov start
-    
+
     # Obtain BigQuery attrs for project and dataset names
     # of the data table
     if (
       "pb_bq_project" %in% names(attributes(tbl)) &&
       "pb_bq_dataset" %in% names(attributes(tbl))
       ) {
-      
+
       bq_project <- attr(tbl, "pb_bq_project", exact = TRUE)
       bq_dataset <- attr(tbl, "pb_bq_dataset", exact = TRUE)
-      
+
       q_types <-
         as.character(
           glue::glue(
@@ -901,19 +952,19 @@ get_tbl_information_dbi <- function(tbl) {
         order by ordinal_position"
           )
         )
-      
+
     } else {
       q_types <- NULL
     }
-    
+
     # nocov end
-  
+
   } else {
 
     if (tbl_src == "mssql") {
-      
+
       # nocov start
-      
+
       q_types <-
         as.character(
           glue::glue(
@@ -921,11 +972,26 @@ get_tbl_information_dbi <- function(tbl) {
           FROM INFORMATION_SCHEMA.COLUMNS WHERE table_name = '{db_tbl_name}'"
           )
         )
-      
+
       # nocov end
-      
-    } else { 
-      
+
+    } else if (tbl_src == "oracle") {
+
+      # nocov start
+
+      q_types <-
+        as.character(
+          glue::glue(
+            "SELECT DATA_TYPE FROM \\
+          USER_TAB_COLUMNS WHERE \\
+          table_name = '{toupper(db_tbl_name)}' AND ROWNUM <= {n_cols}"
+          )
+        )
+
+      # nocov end
+
+    } else {
+
         q_types <-
         as.character(
           glue::glue(
@@ -936,30 +1002,42 @@ get_tbl_information_dbi <- function(tbl) {
         )
     }
   }
-  
+
   # nolint end
-  
+
   if (tbl_src == "postgres") {
-    
+
     # nocov start
-    
-    db_col_types <- 
+
+    db_col_types <-
       DBI::dbGetQuery(tbl_connection, q_types) %>%
       dplyr::pull(data_type) %>%
       tolower()
-    
+
     # nocov end
   }
-  
+
+  if (tbl_src == "oracle") {
+
+    # nocov start
+
+    db_col_types <-
+      DBI::dbGetQuery(tbl_connection, q_types) %>%
+      dplyr::pull(DATA_TYPE) %>%
+      tolower()
+
+    # nocov end
+  }
+
   if (tbl_src %in% c("duckdb", "sqlite")) {
-    
+
     db_col_types <-
       vapply(
         r_column_names_types$col_names,
         FUN.VALUE = character(1),
         USE.NAMES = FALSE,
         FUN = function(x) {
-          
+
           DBI::dbDataType(
             tbl_connection,
             tbl %>%
@@ -972,26 +1050,26 @@ get_tbl_information_dbi <- function(tbl) {
       ) %>%
       tolower()
   }
-  
-  if (!(tbl_src %in% c("duckdb", "sqlite", "postgres"))) {
+
+  if (!(tbl_src %in% c("duckdb", "sqlite", "postgres", "oracle"))) {
 
     # nocov start
-    
-    db_col_types <- 
+
+    db_col_types <-
       DBI::dbGetQuery(tbl_connection, q_types) %>%
       dplyr::collect() %>%
       dplyr::pull(ifelse(tbl_src == "bigquery", "data_type", "DATA_TYPE")) %>%
       tolower()
-    
+
     # nocov end
   }
-  
+
   # nocov start
-  
+
   if (!exists("db_col_types")) {
     db_col_types <- NA_character_
   }
-  
+
   # nocov end
 
   list(
@@ -1010,7 +1088,7 @@ get_tbl_information_dbi <- function(tbl) {
 get_tbl_information_arrow <- function(tbl) {
 
   schema_cap <- utils::capture.output(tbl$schema)[-1][seq_len(ncol(tbl))]
-  
+
   col_names <-
     vapply(
       schema_cap,
@@ -1020,7 +1098,7 @@ get_tbl_information_arrow <- function(tbl) {
         unlist(strsplit(x, split = ": "))[1]
       }
     )
-  
+
   db_col_types <-
     vapply(
       schema_cap,
@@ -1030,7 +1108,7 @@ get_tbl_information_arrow <- function(tbl) {
         unlist(strsplit(x, split = ": "))[2]
       }
     )
-  
+
   r_col_types <-
     vapply(
       dplyr::as_tibble(utils::head(tbl, 1)),
@@ -1038,7 +1116,7 @@ get_tbl_information_arrow <- function(tbl) {
       USE.NAMES = FALSE,
       FUN = function(x) class(x)[1]
     )
-  
+
   list(
     tbl_src = "Arrow",
     tbl_src_details = class(tbl)[1],
@@ -1066,30 +1144,27 @@ pb_fmt_number <- function(
     dec_mark = ".",
     locale = NULL
 ) {
-  
+
   if (is.null(x)) return(NULL)
-  
+
   if (length(x) == 1 &&
       (!inherits(x, "numeric") && !inherits(x, "integer"))) {
     return(x)
-  } 
-  
-  ((dplyr::tibble(a = x) %>%
-      gt::gt() %>%
-      gt::fmt_number(
-        columns = "a",
-        decimals = decimals,
-        n_sigfig = n_sigfig,
-        drop_trailing_zeros = drop_trailing_zeros,
-        drop_trailing_dec_mark = drop_trailing_dec_mark,
-        use_seps = use_seps,
-        scale_by = scale_by,
-        suffixing = suffixing,
-        pattern = pattern,
-        sep_mark = sep_mark,
-        dec_mark = dec_mark,
-        locale = locale
-      ))$`_formats`[[1]][[1]][[1]])(x)
+  }
+  gt::vec_fmt_number(
+    x,
+    decimals = decimals,
+    n_sigfig = n_sigfig,
+    drop_trailing_zeros = drop_trailing_zeros,
+    drop_trailing_dec_mark = drop_trailing_dec_mark,
+    use_seps = use_seps,
+    scale_by = scale_by,
+    suffixing = suffixing,
+    pattern = pattern,
+    sep_mark = sep_mark,
+    dec_mark = dec_mark,
+    locale = locale
+  )
 }
 
 add_icon_img <- function(
@@ -1098,26 +1173,26 @@ add_icon_img <- function(
     v_align = "middle"
 ) {
 
-  file <- 
+  file <-
     system.file(
       "img", "function_icons", paste0(icon, ".png"),
       package = "pointblank"
     )
-  
+
   image_raw <-
     readBin(
       con = file,
       what = "raw",
       n = file.info(file)$size
     )
-  
-  image_uri <- 
+
+  image_uri <-
     paste0(
       "data:image/png;base64,",
       base64enc::base64encode(image_raw, 0)
     )
-  
-  img <- 
+
+  img <-
     htmltools::tags$img(
       src = image_uri,
       alt = icon,
@@ -1126,7 +1201,7 @@ add_icon_img <- function(
         `vertical-align` = v_align
       )
     )
-  
+
   gsub("\\s\\s+", " ", htmltools::HTML(as.character(img)))
 }
 
@@ -1135,13 +1210,13 @@ add_icon_svg <- function(
     height = 30,
     v_align = "middle"
 ) {
-  
-  file <- 
+
+  file <-
     system.file(
       "img", "function_icons", paste0(icon, ".svg"),
       package = "pointblank"
     )
-  
+
   htmltools::tags$div(
     style = htmltools::css(
       margin = 0,
@@ -1174,21 +1249,21 @@ capture_formula <- function(
     remove_whitespace = TRUE,
     oneline = TRUE
 ) {
-  
+
   # TODO: add option to use `htmltools::htmlEscape()`
-  
+
   attributes(formula) <- NULL
-  
+
   output <- utils::capture.output(formula)
-  
+
   if (remove_whitespace) {
     output <- gsub("^\\s+", "", output)
   }
-  
+
   if (oneline) {
     output <- paste(output, collapse = "")
   }
-  
+
   if (separate) {
     if (grepl("^~", output)) {
       output <- c(NA_character_, output)
@@ -1197,19 +1272,19 @@ capture_formula <- function(
       output[2] <- paste("~", output[2])
     }
   }
-  
+
   output
 }
 
 capture_function <- function(fn, escape = TRUE) {
-  
+
   output <- utils::capture.output(fn)
   output <- paste(output[1:(length(output) - 1)], collapse = "\n")
-  
+
   if (escape) {
-    output <- htmltools::htmlEscape(output)  
+    output <- htmltools::htmlEscape(output)
   }
-  
+
   output
 }
 
@@ -1224,13 +1299,13 @@ pb_str_catalog <- function(
     na_rm = FALSE,
     lang = NULL
 ) {
-  
+
   if (is.null(lang)) lang <- "en"
-  
+
   if (na_rm) {
     item_vector <- item_vector[!is.na(item_vector)]
   }
-  
+
   item_count <- length(item_vector)
 
   # If there is nothing in the `item_vector`, return
@@ -1238,29 +1313,29 @@ pb_str_catalog <- function(
   if (item_count < 1) {
     return("---")
   }
-  
+
   if (item_count > 2 && item_count > limit) {
-    
+
     n_items <- item_count - limit
-    
+
     more <- glue::glue(get_lsv("informant_report/snip_list_more")[[lang]])
-    
+
     n_overlimit <- paste0("(", more, ")")
-    
+
     item_vector <- item_vector[1:limit]
-    
+
   } else {
-    
+
     n_overlimit <- ""
   }
 
   if (is.null(quot_str)) {
-    
-    if (is.numeric(item_vector) || 
+
+    if (is.numeric(item_vector) ||
         is.logical(item_vector) ||
         inherits(item_vector, "Date") ||
         inherits(item_vector, "POSIXct")) {
-      
+
       quot_str <- FALSE
     } else {
       quot_str <- TRUE
@@ -1268,11 +1343,11 @@ pb_str_catalog <- function(
   }
 
   surround <- c()
-  
+
   if (quot_str) {
     surround <- "\""
   }
-  
+
   if (as_code) {
     surround <- c(surround, "`")
   }
@@ -1280,7 +1355,7 @@ pb_str_catalog <- function(
   if (is.null(and_or)) {
     and_or <- "and"
   }
-  
+
   if (!(and_or %in% c("and", "or", ""))) {
     stop(
       "The value for `and_or` must be one of the following:\n",
@@ -1288,18 +1363,18 @@ pb_str_catalog <- function(
       call. = FALSE
     )
   }
-  
+
   if (and_or == "") {
-    
+
     # Force the use of all possible commas where the conjunction
     # is not used (this is technically not using an Oxford comma but
     # this proceeds down the same codepath)
     oxford <- TRUE
-    
+
   } else {
-    
+
     and_or <- get_lsv(paste0("informant_report/snip_list_", and_or))[[lang]]
-    
+
     # If a conjunction (the and/or types) is used in any language
     # other than English (where its use is definitely incorrect),
     # then force `oxford` to be FALSE (default is TRUE)
@@ -1310,52 +1385,52 @@ pb_str_catalog <- function(
 
   surround_str_1 <- rev(surround) %>% paste(collapse = "")
   surround_str_2 <- surround %>% paste(collapse = "")
-  
+
   cat_str <- paste0(surround_str_1, item_vector, surround_str_2)
-  
+
   if (item_count == 1) {
-    
+
     return(cat_str)
-    
+
   } else if (item_count == 2) {
-    
+
     return(paste0(cat_str[1], and_or, cat_str[2]))
-    
+
   } else {
-    
+
     separators <- rep(paste0(sep, " "), length(item_vector) - 1)
-    
+
     if (!oxford) {
       separators[length(separators)] <- " "
     }
 
     if (n_overlimit == "") {
-      separators[length(separators)] <- 
+      separators[length(separators)] <-
         paste0(
           separators[length(separators)],
           gsub("(^ | $)", "", and_or),
           " "
         )
     }
-    
+
     separators[length(separators) + 1] <- ""
-    
+
     if (length(cat_str) == 2) {
-      
-      cat_str <- 
+
+      cat_str <-
         paste0(cat_str[1], ", ", cat_str[2])
-      
+
     } else {
-      
+
       cat_str <-
         paste0(cat_str, separators) %>%
         paste(collapse = "")
     }
-    
+
     cat_str <- paste(cat_str, n_overlimit)
-    
+
     cat_str <- gsub("\\s+$", "", cat_str)
-    
+
     return(cat_str)
   }
 }
@@ -1366,17 +1441,17 @@ pb_str_summary <- function(
 ) {
 
   if (type == "5num") {
-    
+
     color <- "dodgerblue"
-    
+
     min_max <- pb_min_max_stats(column)
-    
+
     minimum <- min_max$min
     q1 <- pb_quantile_stats(column, quantile = 0.25)
     median <- pb_quantile_stats(column, quantile = 0.5)
     q3 <- pb_quantile_stats(column, quantile = 0.75)
     maximum <- min_max$max
-    
+
     summary_str <-
       htmltools::tags$span(
         class = "pb_label",
@@ -1395,11 +1470,11 @@ pb_str_summary <- function(
           )
         )
       )
-    
+
   } else if (type == "7num") {
-    
+
     color <- "darkviolet"
-    
+
     p2 <- pb_quantile_stats(column, quantile = 0.02)
     p9 <- pb_quantile_stats(column, quantile = 0.09)
     q1 <- pb_quantile_stats(column, quantile = 0.25)
@@ -1407,7 +1482,7 @@ pb_str_summary <- function(
     q3 <- pb_quantile_stats(column, quantile = 0.75)
     p91 <- pb_quantile_stats(column, quantile = 0.91)
     p98 <- pb_quantile_stats(column, quantile = 0.98)
-    
+
     summary_str <-
       htmltools::tags$span(
         class = "pb_label",
@@ -1428,13 +1503,13 @@ pb_str_summary <- function(
           )
         )
       )
-    
+
   } else if (type == "bowley") {
-    
+
     color <- "orangered"
-    
+
     min_max <- pb_min_max_stats(column)
-    
+
     minimum <- min_max$min
     p10 <- pb_quantile_stats(column, quantile = 0.10)
     q1 <- pb_quantile_stats(column, quantile = 0.25)
@@ -1442,7 +1517,7 @@ pb_str_summary <- function(
     q3 <- pb_quantile_stats(column, quantile = 0.75)
     p90 <- pb_quantile_stats(column, quantile = 0.90)
     maximum <- min_max$max
-    
+
     summary_str <-
       htmltools::tags$span(
         class = "pb_label",
@@ -1464,7 +1539,7 @@ pb_str_summary <- function(
         )
       )
   }
-  
+
   summary_str
 }
 
@@ -1473,9 +1548,9 @@ generate_number <- function(
     color,
     title
 ) {
-  
+
   number <- as.character(number)
-  
+
   u_char <-
     switch(
       number,
@@ -1504,71 +1579,71 @@ pb_quantile_stats <- function(
     data_column,
     quantile
 ) {
-  
+
   if (is_tbl_spark(data_column)) {
-    
+
     # nocov start
-    
+
     column_name <- colnames(data_column)
-    
-    quantile <- 
+
+    quantile <-
       sparklyr::sdf_quantile(
         data_column, column_name,
         probabilities = quantile
-      ) %>% 
+      ) %>%
       unname() %>%
       round(2)
-    
+
     return(quantile)
-    
+
     # nocov end
-    
+
   } else if (inherits(data_column, "data.frame")) {
-    
-    quantile <- 
+
+    quantile <-
       data_column %>%
       stats::quantile(probs = quantile, na.rm = TRUE) %>%
       unname() %>%
       round(2)
-    
+
   } else if (is_tbl_dbi(data_column)) {
-    
+
     data_column <- data_column %>% dplyr::filter(!is.na(1))
-    
-    n_rows <- 
+
+    n_rows <-
       data_column %>%
       dplyr::count(name = "n") %>%
       dplyr::pull(n) %>%
       as.numeric()
-    
+
     if (n_rows <= 5000) {
-      
+
       data_column <- data_column %>% dplyr::collect()
-      
-      quantile <- 
+
+      quantile <-
         data_column %>%
         stats::quantile(probs = quantile, na.rm = TRUE) %>%
         unname() %>%
         round(2)
-      
+
     } else {
-      
-      data_arranged <- 
+
+      data_arranged <-
         data_column %>%
         dplyr::rename(a = 1) %>%
         dplyr::filter(!is.na(a)) %>%
         dplyr::arrange(a) %>%
         utils::head(6E8)
-      
-      n_rows_data <-  
+
+      n_rows_data <-
         data_arranged %>%
         dplyr::count(name = "n") %>%
         dplyr::pull(n) %>%
         as.numeric()
-      
+
       quantile_row <- floor(quantile * n_rows_data)
-      
-      quantile <- 
+
+      quantile <-
         data_arranged %>%
         utils::head(quantile_row) %>%
         dplyr::arrange(desc(a)) %>%
@@ -1577,17 +1652,17 @@ pb_quantile_stats <- function(
         as.numeric() %>%
         round(2)
     }
-    
+
   } else {
-    
+
     stop("This table type isn't yet supported", call. = FALSE)
   }
-  
+
   quantile
 }
 
 pb_min_max_stats <- function(data_column) {
-  
+
   data_column %>%
     dplyr::summarize_all(
       .funs = list(
@@ -1607,10 +1682,10 @@ cli_bullet_msg <- function(
     color = NULL,
     .envir = parent.frame()
 ) {
-  
+
   msg <- glue::glue_collapse(msg, "\n")
   msg <- glue::glue(msg, .envir = .envir)
-  
+
   if (!is.null(color)) {
     color_style <- cli::make_ansi_style(color)
     bullet <- color_style(bullet)
@@ -1630,11 +1705,11 @@ cli_ident <- function(
 }
 
 print_time <- function(time_diff_s) {
-  
+
   if (time_diff_s < 1) {
     return("")
   }
-  
+
   paste0(
     " {.time_taken (",
     round(time_diff_s, 1) %>%
@@ -1643,20 +1718,13 @@ print_time <- function(time_diff_s) {
   )
 }
 
-gt_missing <- 
-  if (packageVersion("gt") >= "0.6.0") {
-    gt::sub_missing 
-  } else {
-    gt::fmt_missing
-  }
-
 pb_get_image_tag <- function(file, dir = "images") {
-  
+
   repo_url <- "https://raw.githubusercontent.com/rstudio/pointblank/main"
-  
+
   function_name <- paste0(gsub("man_(.*)_[1-9].png", "\\1", file), "()")
   example_code_idx <- gsub("man_.*?([1-9]).png", "\\1", file)
-  
+
   ordinal_idx <-
     switch(
       example_code_idx,
@@ -1671,15 +1739,15 @@ pb_get_image_tag <- function(file, dir = "images") {
       `9` = "ninth",
       "above"
     )
-  
+
   alt_text <-
     paste0(
       "This image was generated from the ", ordinal_idx,
       " code example in the `", function_name, "` help file."
     )
-  
+
   image_url <- file.path(repo_url, dir, file)
-  
+
   paste0(
     "<img ",
     "src=\"", image_url, "\" ",
@@ -1691,8 +1759,26 @@ pb_get_image_tag <- function(file, dir = "images") {
 deparse_expr <- function(expr, collapse = " ", ...) {
   if (rlang::is_scalar_atomic(expr)) {
     as.character(expr)
+  } else if (rlang::is_quosure(expr)) {
+    expr <- rlang::quo_get_expr(expr)
+    deparsed <- paste(deparse(expr, ...), collapse = collapse)
+    paste("<expr>", deparsed)
   } else {
     deparsed <- paste(deparse(expr, ...), collapse = collapse)
     paste("<expr>", deparsed)
   }
 }
+
+string_is_valid_symbol <- function(x) {
+  rlang::is_scalar_character(x) &&
+    identical(make.names(x), x)
+}
+
+truncate_expr <- function(x) {
+  if (rlang::is_symbol(x)) {
+    rlang::expr_deparse(x)
+  } else {
+    truncated <- rlang::call2(x[[1]], quote(...))
+    rlang::expr_deparse(truncated)
+  }
+}
