@@ -1,11 +1,11 @@
 test_that("Incorporating an informant yields the correct results", {
-  
+
   # Generate an informant object, add two snippets with `info_snippet()`,
   # add information with some other `info_*()` functions and then
   # `incorporate()` the snippets into the info text
-  informant <- 
+  informant <-
     create_informant(
-      tbl = ~ readr::read_csv(file = "test_table.csv", col_types = "TDdcddlc"),
+      tbl = ~ readr::read_csv(file = testthat::test_path("test_table.csv"), col_types = "TDdcddlc"),
       tbl_name = "test_table",
       label = "An example."
     ) %>%
@@ -36,22 +36,19 @@ test_that("Incorporating an informant yields the correct results", {
       section_name = "rows",
       row_count = "There are {row_count} rows available."
     )
-  
+
   informant_inc <- informant %>% incorporate()
-  
+
   # Expect that names in an informant after using
   # `incorporate()` match a prescribed set of names
-  expect_true(
-    all(
-      names(informant_inc) ==
-        c(
-          "tbl", "read_fn", "tbl_name", "info_label",
-          "meta_snippets",  "lang", "locale",
-          "metadata", "metadata_rev"
-        )
+  expect_named(
+    informant_inc,
+    c(
+      "tbl", "read_fn", "tbl_name", "info_label", "meta_snippets", "lang",
+      "locale", "metadata", "metadata_rev"
     )
   )
-  
+
   # Expect certain names in `informant$metadata` and
   # `informant$metadata_rev`
   expect_equal(
@@ -62,41 +59,39 @@ test_that("Incorporating an informant yields the correct results", {
     names(informant_inc$metadata_rev),
     c("info_label", "table", "columns", "rows", "updated")
   )
-  
+
   # Expect informant objects of class `ptblank_informant`
-  expect_is(informant, "ptblank_informant")
-  expect_is(informant_inc, "ptblank_informant")
-  
+  expect_s3_class(informant, "ptblank_informant")
+  expect_s3_class(informant_inc, "ptblank_informant")
+
   # Don't expect an error if the `read_fn` is valid
-  expect_error(
-    regexp = NA,
+  expect_no_error(
     informant %>% incorporate()
   )
-  expect_error(
-    regexp = NA,
-    informant %>% 
+  expect_no_error(
+    informant %>%
       set_tbl(
-        tbl = function() readr::read_csv(file = "test_table.csv", col_types = "TDdcddlc")
-      ) %>% 
+        tbl = function() readr::read_csv(file = testthat::test_path("test_table.csv"), col_types = "TDdcddlc")
+      ) %>%
       incorporate()
   )
-  
+
   # Get the row and column count values
   n_row_i <- informant_inc$metadata_rev$table$`_rows`
   n_columns_i <- informant_inc$metadata_rev$table$`_columns`
-  
+
   # Modify the internal `read_fn` to read in a slightly altered table
-  informant_inc_2 <- 
+  informant_inc_2 <-
     informant_inc %>%
     set_tbl(
-      tbl = ~ readr::read_csv(file = "test_table_2.csv", col_types = "TDdcddlcd")
+      tbl = ~ readr::read_csv(file = test_path("test_table_2.csv"), col_types = "TDdcddlcd")
     ) %>%
     incorporate()
-  
+
   # Get the row and column count values
   n_row_f <- informant_inc_2$metadata_rev$table$`_rows`
   n_columns_f <- informant_inc_2$metadata_rev$table$`_columns`
-  
+
   expect_equal(
     c(n_row_i, n_row_f), c("13", "26")
   )
@@ -106,12 +101,12 @@ test_that("Incorporating an informant yields the correct results", {
 })
 
 test_that("Incorporating an informant from YAML yields the correct results", {
-  
+
   # Generate an informant object, add two snippets with `info_snippet()`,
   # add information with some other `info_*()` functions
-  informant <- 
+  informant <-
     create_informant(
-      tbl = ~ readr::read_csv(file = "test_table.csv", col_types = "TDdcddlc"),
+      tbl = ~ readr::read_csv(file = test_path("test_table.csv"), col_types = "TDdcddlc"),
       tbl_name = "test_table",
       label = "An example."
     ) %>%
@@ -142,13 +137,13 @@ test_that("Incorporating an informant from YAML yields the correct results", {
       section_name = "rows",
       row_count = "There are {row_count} rows available."
     )
-  
+
   yaml_write(informant, filename = "informant-test_table.yml")
-  
+
   informant_from_yaml <- yaml_read_informant(filename = "informant-test_table.yml")
-  
+
   informant_inc_yaml <- informant_from_yaml %>% incorporate()
-  
+
   # Expect that names in an informant after using
   # `incorporate()` match a prescribed set of names
   expect_true(
@@ -161,7 +156,7 @@ test_that("Incorporating an informant from YAML yields the correct results", {
         )
     )
   )
-  
+
   # Expect certain names in `informant$metadata` and
   # `informant$metadata_rev`
   expect_equal(
@@ -172,49 +167,47 @@ test_that("Incorporating an informant from YAML yields the correct results", {
     names(informant_inc_yaml$metadata_rev),
     c("info_label", "table", "columns", "rows", "updated")
   )
-  
+
   # Expect informant objects of class `ptblank_informant`
-  expect_is(informant, "ptblank_informant")
-  expect_is(informant_inc_yaml, "ptblank_informant")
-  
+  expect_s3_class(informant, "ptblank_informant")
+  expect_s3_class(informant_inc_yaml, "ptblank_informant")
+
   # Don't expect an error if the `read_fn` is valid
-  expect_error(
-    regexp = NA,
+  expect_no_error(
     informant_inc_yaml %>% incorporate()
   )
-  expect_error(
-    regexp = NA,
-    informant_inc_yaml %>% 
+  expect_no_error(
+    informant_inc_yaml %>%
       set_tbl(
-        tbl = function() readr::read_csv(file = "test_table.csv", col_types = "TDdcddlc")
-      ) %>% 
+        tbl = function() readr::read_csv(file = test_path("test_table.csv"), col_types = "TDdcddlc")
+      ) %>%
       incorporate()
   )
-  
+
   # Get the row and column count values
   n_row_i <- informant_inc_yaml$metadata_rev$table$`_rows`
   n_columns_i <- informant_inc_yaml$metadata_rev$table$`_columns`
-  
+
   # Modify the `read_fn` in the YAML file to read in a slightly altered table
   yaml_file_lines <- readLines("informant-test_table.yml")
-  
-  read_fn_line <- which(grepl("tbl:", yaml_file_lines))
-  
-  yaml_file_lines[read_fn_line] <- 
+
+  read_fn_line <- grep("tbl:", yaml_file_lines)
+
+  yaml_file_lines[read_fn_line] <-
     yaml_file_lines[read_fn_line] %>%
     gsub("test_table.csv", "test_table_2.csv", .) %>%
     gsub("TDdcddlc", "TDdcddlcd", .)
-  
+
   writeLines(yaml_file_lines, con = "informant-test_table.yml")
-  
+
   # Incorporate the informant in the YAML file with
   # `yaml_informant_incorporate()` function
   informant_inc_yaml_2 <- yaml_informant_incorporate(filename = "informant-test_table.yml")
-    
+
   # Get the row and column count values
   n_row_f <- informant_inc_yaml_2$metadata_rev$table$`_rows`
   n_columns_f <- informant_inc_yaml_2$metadata_rev$table$`_columns`
-  
+
   expect_equal(
     c(n_row_i, n_row_f), c("13", "26")
   )
@@ -224,3 +217,19 @@ test_that("Incorporating an informant from YAML yields the correct results", {
 })
 
 fs::file_delete(path = "informant-test_table.yml")
+
+test_that("`informant` can materialize table from formula environment (#602)", {
+
+  informant <- local({
+    df <- data.frame(x = 1)
+    create_informant(tbl = ~ df)
+  })
+
+  expect_null(informant$tbl)
+
+  expect_no_error({
+    informant <- informant %>%
+      incorporate()
+  })
+
+})
